@@ -263,9 +263,9 @@ bool Adif::isValidFreq(const QString &_b)
     return false;
 }
 
-bool Adif::isValidPower(const QString &_b)
+bool Adif::isValidPower(const double _b)
 {
-    return (_b.toDouble()>0.0);
+    return (_b >0.0);
 }
 
 QString Adif::getADIFBoolFromBool(const bool _b)
@@ -276,104 +276,104 @@ QString Adif::getADIFBoolFromBool(const bool _b)
 }
 
 
-bool Adif::isValidK_Index(const QString &_b)
+bool Adif::isValidK_Index(const int _b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=9));
+    return ((_b>=0) && (_b<=9));
 }
 
-bool Adif::isValidCQz(const QString &_b)
+bool Adif::isValidCQz(const int _b)
 {
-   return ((_b.toInt()>=1) && (_b.toInt()<=40));
+   return ((_b>=1) && (_b<=40));
 }
 
-bool Adif::isValidITUz(const QString &_b)
+bool Adif::isValidITUz(const int _b)
 {
-    return ((_b.toInt()>=1) && (_b.toInt()<=90));
+    return ((_b>=1) && (_b<=90));
 }
 
-bool Adif::isValidDXCC(const QString &_b)
+bool Adif::isValidDXCC(const int _b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=522));
+    return ((_b>=0) && (_b<=522));
 }
 
-bool Adif::isValidAge(const QString &_b)
+bool Adif::isValidAge(const double _b)
 {
-    return ((_b.toInt()>0) && (_b.toInt()<=120));
+    return ((_b>0.0) && (_b<=120.0));
 }
 
-bool Adif::isValidAnt_EL(const QString &_b)
+bool Adif::isValidAnt_EL(const double _b)
 {
-    return ((_b.toInt()>=-90) && (_b.toInt()<=900));
+    return ((_b>=-90.0) && (_b<=900.0));
 }
 
-bool Adif::isValidAnt_AZ(const QString &_b)
+bool Adif::isValidAnt_AZ(const double _b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=360));
+    return ((_b>=0.0) && (_b<=360.0));
 }
 
-bool Adif::isValidA_Index(const QString &_b)
+bool Adif::isValidA_Index(const double _b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=400));
+    return ((_b>=0.0) && (_b<=400.0));
 }
 
-bool Adif::isValidDistance(const QString &_b)
+bool Adif::isValidDistance(const double _b)
 {
-    return (_b.toDouble()>0);
+    return (_b>0.0);
 }
 
-bool Adif::isValidAltitude(const QString &_b)
+//bool Adif::isValidAltitude(const double _b)
+//{
+//    return true;
+//}
+
+bool Adif::isValidIOTA_islandID(const int _b)
 {
-    return (_b.toDouble()>10000);
+    return ((_b>=1) && (_b<=99999999));
 }
 
-bool Adif::isValidIOTA_islandID(const QString &_b)
+bool Adif::isValidNRBursts(const int _b)
 {
-    return ((_b.toInt()>=1) && (_b.toInt()<=90));
+    return (_b>0);
 }
 
-bool Adif::isValidNRBursts(const QString &_b)
+bool Adif::isValidPings(const int _b)
 {
-    return (_b.toInt()>0);
+    return (_b>0);
 }
 
-bool Adif::isValidPings(const QString &_b)
+bool Adif::isValidSFI(const int _b)
 {
-    return (_b.toInt()>0);
+    return ((_b>=0) && (_b<=300));
 }
 
-bool Adif::isValidSFI(const QString &_b)
+bool Adif::isValidSTX(const int _b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=300));
+    return (_b>=0);
 }
 
-bool Adif::isValidSTX(const QString &_b)
+bool Adif::isValidSRX(const int _b)
 {
-    return (_b.toInt()>=0);
+    return (_b>=0);
 }
 
-bool Adif::isValidSRX(const QString &_b)
+bool Adif::isValidFISTS(const int _b)
 {
-    return (_b.toInt()>=0);
+   return (_b>0);
 }
 
-bool Adif::isValidFISTS(const QString &_b)
+bool Adif::isValidUKSMG(const int _b)
 {
-   return (_b.toInt()>0);
+    return (_b>0);
 }
 
-bool Adif::isValidUKSMG(const QString &_b)
+bool Adif::isValidTenTen(const int _b)
 {
-    return (_b.toInt()>0);
+    return (_b>0);
 }
 
-bool Adif::isValidTenTen(const QString &_b)
+bool Adif::isValidLogId(const int _b)
 {
-    return (_b.toInt()>0);
-}
-
-bool Adif::isValidLogId(const QString &_b)
-{
-    return (_b.toInt()>0);
+    return (_b>0);
 }
 
 bool Adif::isValidAntPath(const QString &_s)
@@ -386,6 +386,17 @@ bool Adif::isValidQSO_COMPLETE(const QString &_s)
     return ((_s == "Y") || (_s == "N") || (_s == "NIL") || (_s == "?"));
 }
 
+int Adif::setQSO_COMPLETEToDB(const QString &_s)
+{
+    if (_s == "Y")
+        return 1;
+    if (_s == "N")
+        return 2;
+    if (_s == "NIL")
+        return 3;
+    return 4;
+}
+
 QString Adif::getQSO_COMPLETEFromDB(const QString &_s)
 {// Returns the ADIF QSO_COMPLETE
     //1=Y, 2=N, 3=NIL, 4=?
@@ -393,22 +404,22 @@ QString Adif::getQSO_COMPLETEFromDB(const QString &_s)
     int i = _s.toInt();
     switch (i)
     {
-    case 2:
-    {
-        return "N";
-    }
-    case 3:
-    {
-        return "NIL";
-    }
-    case 4:
-    {
-        return "?";
-    }
-    default:
-    {
-        return "Y";
-    }
+        case 2:
+        {
+            return "N";
+        }
+        case 3:
+        {
+            return "NIL";
+        }
+        case 4:
+        {
+            return "?";
+        }
+        default:
+        {
+            return "Y";
+        }
     }
 }
 
@@ -420,18 +431,45 @@ bool Adif::isValidPOTA(const QString &_s)
 }
 
 bool Adif::isValidWWFF_Ref(const QString &_s)
-{
-    if (_s.length()<1)
-        return false;
-    return true;
+{ // TODO Add a real check
+    return (!_s.isEmpty());
 }
 
+QStringList Adif::getQSOUploadStatus (bool _fullName)
+{
+    QStringList uploadStatus;
+    if (_fullName)
+        uploadStatus = {"Y - " + tr("Uploaded"), "N - " + tr("Do not Upload"), "M - " + tr("Modified")};
+    else
+        uploadStatus = {"Y", "N", "M"};
+    return uploadStatus;
+}
+
+QStringList Adif::getQSLSentStatus (bool _fullName)
+{
+    QStringList qslStatus;
+    if (_fullName)
+        qslStatus = {"Y - " + tr("Sent"), "N - " + tr("Do not send"), "R - " + tr("Requested"), "Q - " + tr("Queued"), "I - " + tr("Invalid/Ignore")};
+    else
+        qslStatus = {"Y", "N", "R", "Q", "I"};
+    return qslStatus;
+}
+
+QStringList Adif::getQSLRecStatus (bool _fullName)
+{
+    QStringList qslStatus;
+    if (_fullName)
+        qslStatus = {"Y - " + tr("Yes"), "N - " + tr("No"), "R - " + tr("Requested"), "I - " + tr("Invalid/Ignore"), "V - " + tr("Verified")};
+    else
+        qslStatus = {"Y", "N", "R", "I", "V"};
+    return qslStatus;
+}
 
 
 /*
 bool Utilities::isValidComment(const QString &_b)
 {
-    return (_b.length()>0);
+    return (!_b.isEmpty());
 }
 
 bool Utilities::isValidName(const QString &_b)
@@ -692,6 +730,8 @@ QString Adif::getADIFField(const QString &_fieldName, const QString &_data)
     }
 
     QString fieldN = _fieldName.toUpper();
+    //qDebug() << Q_FUNC_INFO << " - toUpper: " << fieldN;
+
     if (!ADIFHash.contains(fieldN)) {
         //qDebug() << Q_FUNC_INFO << " - No valid ADIF: " << _fieldName;
         return QString();
@@ -699,6 +739,7 @@ QString Adif::getADIFField(const QString &_fieldName, const QString &_data)
     if (fieldN == "DISTANCE" )
         if (_data.toDouble() <= 0.0)
             return QString();
+    //qDebug() << Q_FUNC_INFO << " - Returning: " << QString ("<%1:%2>%3 ").arg(fieldN).arg(_data.length ()).arg(_data);
     return QString ("<%1:%2>%3 ").arg(fieldN).arg(_data.length ()).arg(_data);
 }
 
@@ -712,7 +753,7 @@ bool Adif::isValidCall(const QString &_c)
 }
 
 bool Adif::isValidQSLRCVD(const QString &_s, bool _importing)
-{    // Y, I, or V) (V on import only)
+{    // Y, I, or V) (V on import only)    
     return ((_s == "Y") || (_s == "I") || ((_s == "V") && _importing));
 }
 
@@ -725,3 +766,19 @@ void Adif::logEvent(const QString &_func, const QString &_msg,  DebugLogLevel _l
 {
     emit debugLog (_func, _msg, _level);
 }
+
+QString Adif::getADIFDateStringFromLoTWDateTime(const QString &_lotwdatetime)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _lotwdatetime;
+    // LoTW can provide data in two formats:
+    //            2022-04-23T18:08:00Z
+    //            YYYY-MM-DD HH:MM:SS
+    // DateTime should have this format: YYYY-MM-DD HH:MM:SS
+    // It returns a date on YYYYMMDD adif format
+    QDateTime dateTime = QDateTime::fromString(_lotwdatetime, "yyyy-MM-dd HH:mm:ss");
+    //yyyy-MM-ddTHH:mm:ss.zzz (e.g. 2017-07-24T15:46:29.739)
+    //dateTime.fromString(_lotwdatetime, "yyyy-MM-dd HH:mm:ss");
+    //qDebug() << Q_FUNC_INFO << ": Modified date: " << (dateTime.date()).toString("yyyyMMdd");
+    return (dateTime.date()).toString("yyyyMMdd");
+}
+
