@@ -26,13 +26,14 @@
 
 //#include <QDebug>
 
-Awards::Awards(DataProxy_SQLite *dp, const QString &_parentFunction)
+Awards::Awards(DataProxy_SQLite *dp, World *injectedWorld, const QString &_parentFunction)
 {
     Q_UNUSED(_parentFunction);
   //qDebug() << "Awards::Awards- from: " << _parentFunction;
     dataProxy = dp;
     //QSqlDatabase db = QSqlDatabase::database("QSQLITE");
-    world = new World(dataProxy, Q_FUNC_INFO);
+    //world = new World(dataProxy, Q_FUNC_INFO);
+    world = injectedWorld;
 
        //qDebug() << "Awards::Awards - Before DXMarathon" ;
     dxMarathon = new DXMarathon(dataProxy);
@@ -65,7 +66,7 @@ Awards::Awards(DataProxy_SQLite *dp, const QString &_parentFunction)
 
 Awards::~Awards()
 {
-    delete(world);
+    //delete(world);
     delete(dxMarathon);
 }
 
@@ -1200,11 +1201,12 @@ bool Awards::updateDXCCStatus(const int _logNumber)
     }
 
     int qsos = processQueryResults(query);
+    //qDebug() << Q_FUNC_INFO << ": DXCC" << qsos;
     populateDXCCStatusMap(); // Populate the multi-hash map
 
     query.finish();
 
-    return !(dxccStatusList.isEmpty() && qsos > 0);
+    return !(dxccStatusList.isEmpty() && (qsos > 0));
 }
 
 void Awards::populateDXCCStatusMap()
