@@ -43,12 +43,11 @@ StatsWorkedConfirmedPieChartWidget::StatsWorkedConfirmedPieChartWidget(DataProxy
 
 StatsWorkedConfirmedPieChartWidget::~StatsWorkedConfirmedPieChartWidget()
 {
-    delete(dataProxy);
+   //delete(dataProxy);
 }
 
 void StatsWorkedConfirmedPieChartWidget::createUI()
 {
-
     chartView->setRenderHint(QPainter::Antialiasing);
 
     QVBoxLayout *graphLayout = new QVBoxLayout;
@@ -92,5 +91,4 @@ void StatsWorkedConfirmedPieChartWidget::prepareChart(const int _log)
 
     chartView->setRenderHint(QPainter::Antialiasing);
     chartView->setChart (chart);
-
 }
