@@ -46,6 +46,7 @@ enum
     DXCCEntities = 521 // http://www.adif.org/adif302.htm#Country%20Codes
 };
 
+
 class DataProxy_SQLite : public QObject
 {
     Q_OBJECT
@@ -55,6 +56,8 @@ public:
     ~DataProxy_SQLite();
     void setLogLevel (const DebugLogLevel _l);
     QString getSoftVersion();
+    void setPKGVersion(const QString &_pkgVersion);
+    QString getPKGVersion();
     QString getDBVersion();
     bool reconnectDB();
 
@@ -66,8 +69,13 @@ public:
 
     int getIdFromModeName(const QString& _modeName);
     int getIdFromBandName(const QString& _bandName);
-    int getSubModeIdFromSubMode(const QString &_subModeName);
-    int getModeIdFromSubModeId(const int _sm);
+    //int getSubModeIdFromSubMode(const QString &_subModeName);
+
+    bool isValidMode(const QString& _modeName);
+    bool isValidBand(const QString& _bandName);
+
+    //int getModeIdFromSubModeId(const int _sm);
+    bool createHashes();                        // Creates a list of hashes for quick search (band/id & mode/id)
 
     QStringList getFields();
     //KLOG_DEPRECATED QStringList getBands();
@@ -82,7 +90,6 @@ public:
 
     QString getNameFromBandId (const int _id);
     QString getNameFromModeId (const int _id);
-    QString getNameFromSubModeId (const int _id);
 
     QString getSubModeFromId (const int _id);
     QString getNameFromSubMode (const QString &_sm); // Checks if a submode is deprecated TODO: CHeck if really needed
@@ -213,7 +220,9 @@ public:
     QStringList getLongPrefixes();
     QStringList getSpecialCallsigns();
     QHash<QString, int> getWorldData();
-    QStringList getEntitiesNames();
+
+    QHash<QString, int> getHashTableData(const DataTableHash _data);             //Returns a QHash from a Table (Band, Mode, World)
+    QStringList getEntitiesNames(bool _dxccOnly = true);
     QStringList getEntitiesIds();
     int getHowManyEntities();
     int getMaxEntityID(bool limit = true);      // limit = true implies that it will only shouw ARRL valid DXCC (i.e. will not count Sicily)
@@ -277,10 +286,10 @@ public:
     QString getSatelliteFullMode(const QString &_sat);
     QString getSatelliteName(const QString &_sat);
     QString getSateliteArrlIdFromId(const int _id);
-    QStringList getQSLRcvdList();
-    QStringList getQSLSentList();
-    QStringList getClubLogStatusList();
-    QStringList getQSLViaList();
+    //KLOG_DEPRECATED QStringList getQSLRcvdList();
+    //QStringList getQSLSentList();
+    //KLOG_DEPRECATED QStringList getClubLogStatusList();
+    KLOG_DEPRECATED QStringList getQSLViaList();
     int getHowManyQSOPerPropMode(const QString &_p, const int _logn);
 
 
@@ -313,8 +322,8 @@ public:
 
     //void getFoundInLog(const QString &_txt, const int _log=-1);
     //KLOG_DEPRECATED QString getADIFQSO(const int _qsoId, ExportMode _em = ModeADIF);
-    QString getADIFValueFromRec(QSqlRecord _rec, const QString &_fieldName);   // To refactor the getADIFFromQSOQuery function
-    QString getADIFFromQSOQuery(QSqlRecord _rec, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1);
+    KLOG_DEPRECATED QString getADIFValueFromRec(QSqlRecord _rec, const QString &_fieldName);   // Should be optimized to qso::fromDB / qso::getADIF
+    KLOG_DEPRECATED QString getADIFFromQSOQuery(QSqlRecord _rec, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1); // Should be optimized to qso::fromDB / qso::getADIF
     //QString getADIFFromQSOQuery2(QSqlRecord _rec, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1);
 
     bool showInvalidCallMessage(const QString &_call);
@@ -323,6 +332,7 @@ public:
 
     QList<QSO*> getGridStats(int _log=-1);
     QList<QSO*> getSatDXCCStats(int _log=-1);
+
     int getFieldInBand(ValidFieldsForStats _field, const QString &_band, bool confirmedOnly, QString _mode = "ALL", int _log=-1);
     //bool queryPrepare(const QString &_query);
     //bool queryBind(const QString &_field, const QString &value);
@@ -337,6 +347,7 @@ private:
     QString getStringQueryStationCallSign (const QString &_a);      // Creates part of a query regarding the station_call field
     QString getStringQueryMyGrid (const QString &_a);               // Creates part of a query regarding the my_gridsquare field
     QString getStringQueryLogNumber (const int _a);                 // Creates part of a query regarding the lognumber field
+    void mapModeNameSubmode();                                      // Maps mode/Submode/id using submodeToName & nameToMainId
     //KLOG_DEPRECATED int getPrefixId(const QString &_qrz);           // TODO: Replace by int World::getPrefixId(const QString &_prefix)
                                // Refactored from fillEmptyDXCCInTheLog
     //bool updateDXCCAndContinent(const int _id, const int _dxcc, const QString &_cont); // Refactored from fillEmptyDXCCInTheLog
@@ -347,6 +358,16 @@ private:
     int executionN;
     Utilities *util;
     DebugLogLevel logLevel;
+    QString pkgVersion;
+
+    QHash<QString, int> bandIDs;
+    QHash<QString, int> modeIDs;
+
+
+    QHash<int, QString> modeIdToName;
+    QHash<QString, QList<int>> nameToModeIds;
+
+
     //QSqlQuery preparedQuery;
     //QSqlRelationalTableModel *logModel;
 private slots:
