@@ -36,7 +36,7 @@ TODO: Call the creation of this depending on the bands that the user is using
 */
 
 
-DXCCStatusWidget::DXCCStatusWidget(Awards *awards, QWidget *parent) :
+DXCCStatusWidget::DXCCStatusWidget(Awards *awards, World *injectedWorld, QWidget *parent) :
     QWidget(parent),
     awards(awards) // Initialize Awards reference
 {   
@@ -51,7 +51,8 @@ DXCCStatusWidget::DXCCStatusWidget(Awards *awards, QWidget *parent) :
     //wards = new Awards(dataProxy, Q_FUNC_INFO);
       //qDebug() << Q_FUNC_INFO << " - -1";
 
-    world = new World(dataProxy,Q_FUNC_INFO);
+    //world = new World(dataProxy,Q_FUNC_INFO);
+    world = injectedWorld;
       //qDebug() << Q_FUNC_INFO << " - -2";
 
     dxccView = new QTableWidget;
@@ -76,7 +77,7 @@ DXCCStatusWidget::DXCCStatusWidget(Awards *awards, QWidget *parent) :
 DXCCStatusWidget::~DXCCStatusWidget()
 {
     delete(locator);
-    delete(world);
+    //delete(world);
     //delete(awards);
 }
 
@@ -185,13 +186,13 @@ void DXCCStatusWidget::update()
     //int entities = dataProxy->getMaxEntityID(false);        // REMOVE IF processEntities does not need it
     if (!awards->updateDXCCStatus (-1)) // We update all
     {
-       //qDebug() << Q_FUNC_INFO << "awards->updateDXCCStatus returned FALSE";
+        //qDebug() << Q_FUNC_INFO << "awards->updateDXCCStatus returned FALSE";
         // It may be the case that DXCC field in the table is not defined.
         // It should be updated.
         handleDXCCStatusUpdateFailure();
         return;
     }
-   //qDebug() << Q_FUNC_INFO << "awards->updateDXCCStatus returned TRUE";
+    //qDebug() << Q_FUNC_INFO << "awards->updateDXCCStatus returned TRUE";
 
     processEntities();
 
@@ -411,11 +412,9 @@ void DXCCStatusWidget::fillData()
     //if (_creating)
     //{
     //qDebug() << Q_FUNC_INFO << " - 121";
-        update();
+    update();
     //}
    //qDebug() << Q_FUNC_INFO << " - END";
-
-
 }
 
 void DXCCStatusWidget::resetDXCCView()
@@ -453,12 +452,12 @@ void DXCCStatusWidget::setDefaultBands()
 void DXCCStatusWidget::slotRefreshButtonClicked()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-   //qDebug() << Q_FUNC_INFO << " - Start";
+    //qDebug() << Q_FUNC_INFO << " - Start";
 
     //TODO: Define a way to show the status of the selected log or all the logs in the DB
     if (dxccView->rowCount()<1)
     {
-       //qDebug() << Q_FUNC_INFO << " - rowcount <1";
+        //qDebug() << Q_FUNC_INFO << " - rowcount <1";
         return;
     }
     //QStringList _bands = bandNames;
@@ -467,14 +466,14 @@ void DXCCStatusWidget::slotRefreshButtonClicked()
 
     //emit updateAwards();
     //update();
-  //qDebug() << Q_FUNC_INFO << " - END";
+    //qDebug() << Q_FUNC_INFO << " - END";
     emit debugLog (Q_FUNC_INFO, "END", Debug);
 }
 
 void DXCCStatusWidget::refresh()
 {
     emit debugLog (Q_FUNC_INFO, "Start", Debug);
-   //qDebug() << Q_FUNC_INFO << " - Start";
+    //qDebug() << Q_FUNC_INFO << " - Start";
     //update();
     slotRefreshButtonClicked();
     emit debugLog (Q_FUNC_INFO, "END", Debug);
@@ -656,7 +655,7 @@ void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
           }
         }
         //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of for" ;
-        if (qsos.length()>0)
+        if (!qsos.isEmpty())
         {
             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - qsos.length = " << QString::number(qsos.length()) ;
             emit showQsos(qsos);
