@@ -27,7 +27,7 @@ email                : jaime@robles.es
 #include "dxcluster.h"
 #include "../callsign.h"
 
-DXClusterWidget::DXClusterWidget(Awards *awards, QWidget *parent)
+DXClusterWidget::DXClusterWidget(Awards *awards, World *injectedWorld, QWidget *parent)
           : QWidget(parent),
             awards(awards),
             dataProxy(awards->dataProxy)
@@ -40,7 +40,8 @@ DXClusterWidget::DXClusterWidget(Awards *awards, QWidget *parent)
     util = new Utilities(Q_FUNC_INFO);
     //util->setLongPrefixes(dataProxy->getLongPrefixes());
     //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
-    world = new World(dataProxy, Q_FUNC_INFO);
+    //world = new World(dataProxy, Q_FUNC_INFO);
+    world = injectedWorld;
     //awards = new Awards(dataProxy, Q_FUNC_INFO);
 
     tcpSocket = new QTcpSocket(this);
@@ -97,7 +98,7 @@ DXClusterWidget::~DXClusterWidget()
    //qDebug() << Q_FUNC_INFO;
     //delete(dataProxy);
     delete(tcpSocket);
-    delete(world);
+    //delete(world);
     delete(util);
     delete(saveSpotsFile);
 }
@@ -287,7 +288,7 @@ void DXClusterWidget::slotClusterDataArrived()
 {
    //qDebug() << Q_FUNC_INFO;
     QString dxClusterString = tcpSocket->readAll().trimmed().simplified();
-   //qDebug() << Q_FUNC_INFO << " - 010:" << dxClusterString;
+  //qDebug() << Q_FUNC_INFO << " - 010:" << dxClusterString;
 
     if (dxClusterString.endsWith("\x07\x07\r\n"))
     {
@@ -837,6 +838,23 @@ void DXClusterWidget::loadSettings()
         setDXClusterServer((aux.split(':', QT_SKIP)).at(0), ((aux.split(':', QT_SKIP)).at(1)).toInt());
     }
 
+    showhf      = settings.value("DXClusterShowHF").toBool();
+    showvhf     = settings.value("DXClusterShowVHF").toBool();
+    showwarc    = settings.value("DXClusterShowWARC").toBool();
+    showwcy     = settings.value("DXClusterShowWCY").toBool();
+    showwwv     = settings.value("DXClusterShowWWV").toBool();
+    showann     = settings.value("DXClusterShowAnn").toBool();
+    showworked  = settings.value("DXClusterShowWorked").toBool();
+    showconfirmed = settings.value("DXClusterShowConfirmed").toBool();
+    saveSpots   = settings.value("DXClusterSave").toBool();
+
+/*
+        DXClusterSendToMap=true
+        DXClusterServerToUse=
+        DXClusterServers\1\Server=dxfun.com:8000
+                                    DXClusterServers\size=1
+
+*/
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
