@@ -43,7 +43,6 @@
 #include "awards.h"
 #include "database.h"
 #include "dataproxy_sqlite.h"
-#include "dataproxy_sqlite.h"
 #include "utilities.h"
 #include "qso.h"
 
@@ -61,8 +60,10 @@ enum
 class FileManager : public QWidget
 {
     Q_OBJECT
+    friend class tst_FileManager;
+
 public:
-    FileManager(DataProxy_SQLite *dp);
+    FileManager(DataProxy_SQLite *dp, World *injectedWorld);
     //FileManager(DataProxy_SQLite *dp, const QString &_klogDir);
     //FileManager(DataProxy_SQLite *dp, const QString &_klogDir);
     //FileManager(DataProxy_SQLite *dp, const QString &_softVersion);
@@ -70,15 +71,15 @@ public:
     void init();
     //bool readAdif(const QString& tfileName, const int logN);
     //bool adifReadLog(const QString& tfileName, const int logN);
-    int adifReadLog2(const QString& tfileName, QString _stationCallsign = QString(), int logN = -1);
+    int adifReadLog(const QString& tfileName, QString _stationCallsign = QString(), int logN = -1);
     int adifLoTWReadLog2(const QString& fileName, const int logN);
     //QList<int> adifLoTWLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
     //QList<int> (const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const bool LoTWOnly);
 
-    bool adifQSOsExport(const QString& _fileName, QList<int> _qsos);
+    //bool adifQSOsExport(const QString& _fileName, QList<int> _qsos);
     bool adifQSOsExport2(const QString& _fileName, const QString& _fields, QList<int> _qsos, ExportMode _em);
-    QList<int> adifLogExportReturnList(const QString& _fileName, const QString &_callsign, const QString &_grid, const QDate &_startDate, const QDate &_endDate, const int _logN, const ExportMode _em);
-    QList<int> adifLogExportReturnList2(const QString& _fileName, const QString &_callsign, QList<int> _qsos, const ExportMode _em, const int _logN);
+
+    QList<int> adifLogExportReturnList(const QString& _fileName, const QString &_callsign, QList<int> _qsos, const ExportMode _em, const int _logN);
     bool adifLogExport(const QString& _fileName, const int _logN);
     bool adifLogExportMarked(const QString& _fileName);
     bool adifReqQSLExport(const QString& _fileName);
@@ -95,9 +96,11 @@ private:
     //bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
     //bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
     //bool adifCheckMoreThanOneLog(QFile &_f);
+    bool isALoTWDownloadedFile(QFile & _f);
     int howManyLogsInFile(QFile & _f);
     int howManyQSOsInFile (QFile & _f);
     qint64 passHeader(QFile & _f);
+    QString getProgramID (QFile &_f);
 
     bool fillHashLog(QFile & _f);
     QStringList getListOfLogsInFile(QFile & _f);
@@ -105,6 +108,8 @@ private:
     bool getStationCallsignFromUser(const QString &_qrzDX, const QDate &_dt);
     bool showInvalidCallMessage(const QString &_call);
     void showError (const QString &_txt);
+    bool handleCancel();                        // Used in FileManager::adifReadLog
+    int processQSO(QSO& qso, const QString& _stationCallsign); // Used in FileManager::adifReadLog
 
     bool askUserToUseAlwaysSameAnswer();
     bool askUserToAddThisQSOToLog(const QString &_call, const QDateTime _datetime, const QString &_mode, const QString &_band, const double _freq);
@@ -116,10 +121,9 @@ private:
 
     bool checkADIFValidFormat(const QStringList &_qs);
 
-    QStringList readAdifField (const QString &_field);
     // void writeAdifField(const QString &_field, const QString &_data); // It should possibly receive also the QTextStream
 
-    void writeQuery(QSqlRecord &rec, QTextStream &out, const ExportMode _em, const bool _justMarked, const bool _onlyRequested, const int _logN);
+    KLOG_DEPRECATED void writeQuery(QSqlRecord &rec, QTextStream &out, const ExportMode _em, const bool _justMarked, const bool _onlyRequested, const int _logN);
     void writeADIFHeader(QTextStream &out, const ExportMode _em, const int _numberOfQsos);
 
 
@@ -149,7 +153,7 @@ private:
                             // KLog sets or not a default value
     int duplicatedQSOSlotInSecs;
 
-    World *world;
+    //World *world;
     Awards *awards;
     //QSqlDatabase db;
 
