@@ -25,6 +25,8 @@
  *****************************************************************************/
 
 #include "mainwindowinputeqsl.h"
+#include "../adif.h"
+
 
 MainWindowInputEQSL::MainWindowInputEQSL(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
@@ -61,6 +63,7 @@ MainWindowInputEQSL::~MainWindowInputEQSL()
 
 QSO MainWindowInputEQSL::getQSOData(QSO _qso)
 {
+   //qDebug() << Q_FUNC_INFO;
     QSO qso = _qso;
     qso.setClubLogStatus(getClubLogStatus());
     qso.setEQSLQSL_RCVD(getEQSLRecStatus());
@@ -81,33 +84,44 @@ QSO MainWindowInputEQSL::getQSOData(QSO _qso)
 
 void MainWindowInputEQSL::setQSOData(const QSO &_qso)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QSO qso(_qso);
+    // Define first the status so the slots are not overwriting the dates or set uo a semaphore
+
+    //qDebug() << Q_FUNC_INFO << (_qso.getEQSLQSLSDate()).toString("yyyy-MM-dd");
+    //qDebug() << Q_FUNC_INFO << (qso.getEQSLQSLSDate()).toString("yyyy-MM-dd");
     setClubLogStatus(qso.getClubLogStatus());
     setClubLogDate(qso.getClubLogDate());
 
-    setEQSLRecDate(qso.getEQSLQSLRDate());
-    setEQSLSenDate(qso.getEQSLQSLSDate());
     setEQSLRecStatus(qso.getEQSLQSL_RCVD());
     setEQSLSenStatus(qso.getEQSLQSL_SENT());
+    setEQSLRecDate(qso.getEQSLQSLRDate());
+    setEQSLSenDate(qso.getEQSLQSLSDate());
 
-    setLOTWRecDate(qso.getLoTWQSLRDate());
-    setLOTWSenDate(qso.getLoTWQSLSDate());
     setLOTWRecStatus(qso.getLoTWQSL_RCVD());
     setLOTWSenStatus(qso.getLoTWQSL_SENT());
+    setLOTWRecDate(qso.getLoTWQSLRDate());
+    setLOTWSenDate(qso.getLoTWQSLSDate());
 
-    setQRZCOMDate(qso.getQRZCOMDate());
     setQRZCOMStatus(qso.getQRZCOMStatus());
+    setQRZCOMDate(qso.getQRZCOMDate());    
 }
 
 void MainWindowInputEQSL::createUI()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     qslSentStatusList.clear();
     qslRcvdStatusList.clear();
     clubLogStatusList.clear();
-    qslSentStatusList = dataProxy->getQSLSentList();
-    qslRcvdStatusList = dataProxy->getQSLRcvdList();
-    clubLogStatusList = dataProxy->getClubLogStatusList();
+    Adif adif(Q_FUNC_INFO);
+    qslSentStatusList = adif.getQSLSentStatus(true);
+    //qslSentStatusList = dataProxy->getQSLSentList();
 
+    qslRcvdStatusList = adif.getQSLRecStatus (true);
+    //dataProxy->getQSLRcvdList();
+
+    //clubLogStatusList = dataProxy->getClubLogStatusList();
+    clubLogStatusList = adif.getQSOUploadStatus(true);
     eqslSentQDateEdit->setDisplayFormat("dd/MM/yyyy");
     eqslRecQDateEdit->setDisplayFormat("dd/MM/yyyy");
     lotwSentQDateEdit->setDisplayFormat("dd/MM/yyyy");
@@ -185,6 +199,7 @@ void MainWindowInputEQSL::createUI()
 
 void MainWindowInputEQSL::setDefaultData()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     //qsAux << tr("Y-Yes") << tr("N-No") << tr("R-Requested") << tr("I-Ignore") << tr("V-Validated");
 
     //eqslRecComboBox->addItems(qsAux);
@@ -209,22 +224,12 @@ void MainWindowInputEQSL::setDefaultData()
 
 void MainWindowInputEQSL::clear()
 {
-      //qDebug() << "MainWindowInputEQSL::clear" ;
-     // Do not upload
-    if (queueSentByDefault)
-    {
-        clublogComboBox->setCurrentIndex( clublogComboBox->findText("M", Qt::MatchStartsWith));
-        eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText("Q", Qt::MatchStartsWith));
-        lotwSentComboBox->setCurrentIndex( lotwSentComboBox->findText("Q", Qt::MatchStartsWith));
-        qrzcomComboBox->setCurrentIndex( qrzcomComboBox->findText("M", Qt::MatchStartsWith));
-    }
-    else
-    {
-        clublogComboBox->setCurrentIndex( clublogComboBox->findText("N", Qt::MatchStartsWith));
-        qrzcomComboBox->setCurrentIndex( qrzcomComboBox->findText("N", Qt::MatchStartsWith));
-        eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText("N", Qt::MatchStartsWith));
-        lotwSentComboBox->setCurrentIndex( lotwSentComboBox->findText("N", Qt::MatchStartsWith));
-    }
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    // Do not upload
+    clublogComboBox->setCurrentIndex( clublogComboBox->findText(clublogSentDefault, Qt::MatchStartsWith));
+    eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText(eqslSentDefault, Qt::MatchStartsWith));
+    lotwSentComboBox->setCurrentIndex( lotwSentComboBox->findText(lotwSentDefault, Qt::MatchStartsWith));
+    qrzcomComboBox->setCurrentIndex( qrzcomComboBox->findText(qrzcomSentDefault, Qt::MatchStartsWith));
 
     eqslRecComboBox->setCurrentIndex(eqslRecComboBox->findText("N", Qt::MatchStartsWith));
     lotwRecComboBox->setCurrentIndex(lotwRecComboBox->findText("N", Qt::MatchStartsWith));
@@ -240,6 +245,7 @@ void MainWindowInputEQSL::clear()
 
 QString MainWindowInputEQSL::getClubLogStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QString _pm = QString();
    //qDebug() << Q_FUNC_INFO << clublogComboBox->currentText();
      _pm = (((clublogComboBox->currentText()).split('-')).at(0)).simplified();
@@ -249,6 +255,7 @@ QString MainWindowInputEQSL::getClubLogStatus()
 
 QString MainWindowInputEQSL::getQRZCOMStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QString _pm = QString();
     _pm = (((qrzcomComboBox->currentText()).split('-')).at(0)).simplified();
     //qDebug() << Q_FUNC_INFO << " - From UI: " << _pm;
@@ -257,6 +264,7 @@ QString MainWindowInputEQSL::getQRZCOMStatus()
 
 QString MainWindowInputEQSL::getEQSLRecStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
    QString _pm = QString();
     //qDebug() << "MainWindowInputEQSL::getEQSLRecStatus:" << eqslRecComboBox->currentText();
     _pm = (((eqslRecComboBox->currentText()).split('-')).at(0)).simplified();
@@ -270,6 +278,7 @@ QString MainWindowInputEQSL::getEQSLRecStatus()
 
 QString MainWindowInputEQSL::getEQSLSenStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QString _pm = QString();
      //qDebug() << "MainWindowInputEQSL::getEQSLSenStatus:" << eqslSentComboBox->currentText();
      _pm = (((eqslSentComboBox->currentText()).split('-')).at(0)).simplified();
@@ -283,6 +292,7 @@ QString MainWindowInputEQSL::getEQSLSenStatus()
 
 QString MainWindowInputEQSL::getLOTWRecStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QString _pm = QString();
      //qDebug() << "MainWindowInputEQSL::getLOTWRecStatus:" << lotwRecComboBox->currentText();
      _pm = (((lotwRecComboBox->currentText()).split('-')).at(0)).simplified();
@@ -296,6 +306,7 @@ QString MainWindowInputEQSL::getLOTWRecStatus()
 
 QString MainWindowInputEQSL::getLOTWSenStatus()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QString _pm = QString();
      //qDebug() << "MainWindowInputEQSL::getLOTWSenStatus:" << lotwSentComboBox->currentText();
      _pm = (((lotwSentComboBox->currentText()).split('-')).at(0)).simplified();
@@ -310,8 +321,8 @@ QString MainWindowInputEQSL::getLOTWSenStatus()
 
 void MainWindowInputEQSL::setClubLogStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs;
-    if((( clublogComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
+    if((( clublogComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      {
          clublogComboBox->setCurrentIndex( clublogComboBox->findText(_qs+" -", Qt::MatchStartsWith));
      }
@@ -323,8 +334,8 @@ void MainWindowInputEQSL::setClubLogStatus(const QString &_qs)
 
 void MainWindowInputEQSL::setQRZCOMStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setClubLogStatus: " << _qs;
-    if((( qrzcomComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+    //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
+    if((( qrzcomComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      {
          qrzcomComboBox->setCurrentIndex( qrzcomComboBox->findText(_qs+" -", Qt::MatchStartsWith));
      }
@@ -336,9 +347,9 @@ void MainWindowInputEQSL::setQRZCOMStatus(const QString &_qs)
 
 void MainWindowInputEQSL::setEQSLRecStatus(const QString &_qs)
 {
-       //qDebug() << "MainWindowInputEQSL::setEQSLRecStatus: " << _qs;
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
      //if(( eqslRecComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
-    if((( eqslRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+    if((( eqslRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      {
          eqslRecComboBox->setCurrentIndex( eqslRecComboBox->findText(_qs+" -", Qt::MatchStartsWith));
      }
@@ -350,9 +361,9 @@ void MainWindowInputEQSL::setEQSLRecStatus(const QString &_qs)
 
 void MainWindowInputEQSL::setEQSLSenStatus(const QString &_qs)
 {
-    //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: #" << _qs+" -";
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
 
-     if((( eqslSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+     if((( eqslSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      {
          //qDebug() << "MainWindowInputEQSL::setEQSLSenStatus: found: " << _qs << " - Index: " << QString::number(eqslSentComboBox->findText(_qs, Qt::MatchStartsWith));
          eqslSentComboBox->setCurrentIndex( eqslSentComboBox->findText(_qs, Qt::MatchStartsWith));
@@ -380,8 +391,8 @@ void MainWindowInputEQSL::setEQSLSenStatus(const QString &_qs)
 
 void MainWindowInputEQSL::setLOTWRecStatus(const QString &_qs)
 {
-      //qDebug() << "MainWindowInputEQSL::setLOTWRecStatus: " << _qs;
-    if((( lotwRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
+    if((( lotwRecComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      //if(( lotwRecComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
      {
          lotwRecComboBox->setCurrentIndex( lotwRecComboBox->findText(_qs+" -", Qt::MatchStartsWith));
@@ -395,8 +406,8 @@ void MainWindowInputEQSL::setLOTWRecStatus(const QString &_qs)
 
 void MainWindowInputEQSL::setLOTWSenStatus(const QString &_qs)
 {
-      //qDebug() << "MainWindowInputEQSL::setLOTWSenStatus: " << _qs;
-    if((( lotwSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (_qs.length()>0)    )
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _qs;
+    if((( lotwSentComboBox->findText(_qs, Qt::MatchStartsWith))>=0) && (!_qs.isEmpty())    )
      //if(( lotwSentComboBox->findText(_qs+" -", Qt::MatchStartsWith))>=0)
      {
          lotwSentComboBox->setCurrentIndex( lotwSentComboBox->findText(_qs+" -", Qt::MatchStartsWith));
@@ -417,8 +428,9 @@ void MainWindowInputEQSL::setLOTWSenStatus(const QString &_qs)
 }
 
 
-void MainWindowInputEQSL::slotLotwRecvComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::slotLotwRecvComboBoxChanged";
+void MainWindowInputEQSL::slotLotwRecvComboBoxChanged()
+{
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
 
 //QSLRDATE (only valid if QSL_RCVD is Y-0, I-3, or V-4)
 //Y-Yes-0
@@ -457,8 +469,9 @@ void MainWindowInputEQSL::slotLotwRecvComboBoxChanged(){
 }
 
 
-void MainWindowInputEQSL::slotLotwSentComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::slotLotwSentComboBoxChanged";
+void MainWindowInputEQSL::slotLotwSentComboBoxChanged()
+{
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
 
     int i = lotwSentComboBox->currentIndex();
 //{Y, N, R, I, V}
@@ -499,8 +512,9 @@ void MainWindowInputEQSL::slotLotwSentComboBoxChanged(){
 }
 
 
-void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::sloteQSLRecvComboBoxChanged";
+void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged()
+{
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
 
 //QSLRDATE (only valid if QSL_RCVD is Y-0, I-3, or V-4)
 //Y-Yes-0
@@ -541,8 +555,9 @@ void MainWindowInputEQSL::sloteQSLRecvComboBoxChanged(){
 }
 
 
-void MainWindowInputEQSL::sloteQSLSentComboBoxChanged(){
-       //qDebug() << "MainWindowInputEQSL::sloteQSLSentComboBoxChanged";
+void MainWindowInputEQSL::sloteQSLSentComboBoxChanged()
+{
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
 
     int i = eqslSentComboBox->currentIndex();
 //{Y, N, R, I, V}
@@ -584,6 +599,7 @@ void MainWindowInputEQSL::sloteQSLSentComboBoxChanged(){
 
 void MainWindowInputEQSL::slotClubLogComboBoxChanged()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     int i = clublogComboBox->currentIndex();
     //{Y, N, M}
     // Y-Yes = 0
@@ -611,7 +627,7 @@ void MainWindowInputEQSL::slotClubLogComboBoxChanged()
 
 void MainWindowInputEQSL::setClubLogDate(const QDate _qs)
 {
-   //qDebug() << Q_FUNC_INFO << "Date: " << _qs.toString("dd/MM/yyyy");
+  //qDebug() << Q_FUNC_INFO << "Date: " << _qs.toString("dd/MM/yyyy");
     if (_qs.isValid())
     {
         clublogQDateEdit->setDate(_qs);
@@ -624,6 +640,7 @@ void MainWindowInputEQSL::setClubLogDate(const QDate _qs)
 
 void MainWindowInputEQSL::slotQRZCOMComboBoxChanged()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     int i = qrzcomComboBox->currentIndex();
     //{Y, N, M}
     // Y-Yes = 0
@@ -651,6 +668,7 @@ void MainWindowInputEQSL::slotQRZCOMComboBoxChanged()
 
 void MainWindowInputEQSL::setQRZCOMDate(const QDate _qs)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     if (_qs.isValid())
     {
         qrzcomQDateEdit->setDate(_qs);
@@ -663,6 +681,7 @@ void MainWindowInputEQSL::setQRZCOMDate(const QDate _qs)
 
 void MainWindowInputEQSL::setEQSLRecDate(const QDate _qs)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: " ;
     if (_qs.isValid())
     {
         eqslRecQDateEdit->setDate(_qs);
@@ -675,18 +694,22 @@ void MainWindowInputEQSL::setEQSLRecDate(const QDate _qs)
 
 void MainWindowInputEQSL::setEQSLSenDate(const QDate _qs)
 {
+   //qDebug() << Q_FUNC_INFO << (_qs).toString("yyyy-MM-dd");
     if (_qs.isValid())
     {
+        //qDebug() << Q_FUNC_INFO << " - Date valid";
         eqslSentQDateEdit->setDate(_qs);
     }
     else
     {
+        //qDebug() << Q_FUNC_INFO << " - Date not valid";
         eqslSentQDateEdit->setDate(QDate::currentDate());
     }
 }
 
 void MainWindowInputEQSL::setLOTWRecDate(const QDate _qs)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     if (_qs.isValid())
     {
         lotwRecQDateEdit->setDate(_qs);
@@ -699,6 +722,7 @@ void MainWindowInputEQSL::setLOTWRecDate(const QDate _qs)
 
 void MainWindowInputEQSL::setLOTWSenDate(const QDate _qs)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     if (_qs.isValid())
     {
         lotwSentQDateEdit->setDate(_qs);
@@ -711,26 +735,31 @@ void MainWindowInputEQSL::setLOTWSenDate(const QDate _qs)
 
 QDate MainWindowInputEQSL::getClubLogDate()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     return clublogQDateEdit->date();
 }
 
 QDate MainWindowInputEQSL::getQRZCOMDate()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     return qrzcomQDateEdit->date();
 }
 
 QDate MainWindowInputEQSL::getEQSLRecDate()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     return eqslRecQDateEdit->date();
 }
 
 QDate MainWindowInputEQSL::getEQSLSenDate()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     return eqslSentQDateEdit->date();
 }
 
 QDate MainWindowInputEQSL::getLOTWRecDate()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: ";
     return   lotwRecQDateEdit->date();
 }
 
@@ -739,7 +768,32 @@ QDate MainWindowInputEQSL::getLOTWSenDate()
     return lotwSentQDateEdit->date();
 }
 
-void MainWindowInputEQSL::setQueueSentByDefault(const bool _b)
+
+void MainWindowInputEQSL::loadSettings()
 {
-    queueSentByDefault = _b;
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+
+    settings.beginGroup ("ClubLog");
+    clublogSentDefault = settings.value("ClubLogSentDefault", "M").toString();
+    settings.endGroup ();
+
+    settings.beginGroup ("eQSL");
+    eqslSentDefault = settings.value("eQSLSentDefault", "Q").toString();
+    settings.endGroup ();
+
+    settings.beginGroup ("QRZcom");
+    qrzcomSentDefault = settings.value("QRZcomSentDefault", "M").toString();
+    settings.endGroup ();
+
+    settings.beginGroup ("LoTW");
+    lotwSentDefault = settings.value("LoTWSentDefault", "Q").toString();
+    settings.endGroup ();
+
+    settings.beginGroup ("Misc");
+    queueSentByDefault = settings.value ("SendEQSLByDefault", true).toBool ();
+    settings.endGroup ();
+    //qDebug() << Q_FUNC_INFO << " - END";
+
+    //logEvent (Q_FUNC_INFO, "END", Debug);
 }
