@@ -29,13 +29,14 @@
 #include "../adif.h"
 #include "../callsign.h"
 
-MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent) :
+MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, World *injectedWorld, QWidget *parent) :
     QWidget(parent)
 {
        //qDebug() << Q_FUNC_INFO;
     logLevel = None;
     dataProxy = dp;
-    world = new World(dataProxy,Q_FUNC_INFO);
+    //world = new World(dataProxy,Q_FUNC_INFO);
+    world = injectedWorld;
 
     util = new Utilities(Q_FUNC_INFO);
     //util->setLongPrefixes(dataProxy->getLongPrefixes());
@@ -58,14 +59,14 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *pare
     //connect(satTabWidget, SIGNAL(setPropModeSat(QString)), this, SLOT(slotSetPropMode(QString)) ) ;
     connect(entityNameComboBox,             SIGNAL(currentIndexChanged(int)),   this, SLOT(slotEntityNameComboBoxChanged() ) ) ;
     connect(propModeComboBox,               SIGNAL(currentIndexChanged(int)),   this, SLOT(slotPropModeComboBoxChanged() ) ) ;
-    connect(userDefinedADIFComboBox,        SIGNAL(currentIndexChanged(int)),   this, SLOT(slotUSerDefinedADIFComboBoxChanged() ) ) ;
+    connect(userDefinedADIFComboBox,        SIGNAL(currentIndexChanged(int)),   this, SLOT(slotUserDefinedADIFComboBoxChanged() ) ) ;
     connect(userDefinedADIFValueLineEdit,   SIGNAL(textChanged(QString)),       this, SLOT(slotSetCurrentUserData() ) );
     connect(entityPrimDivComboBox,          SIGNAL(currentIndexChanged(int)),   this, SLOT(slotPrimarySubdivisionsComboBoxChanged()) )  ;
     connect(showAllCheckBox,                SIGNAL(stateChanged(int)),          this, SLOT(slotShowAllCheckBoxChanged() ) ) ;
 
     createUI();
     setInitialADIFValues ();
-       //qDebug() << Q_FUNC_INFO << ": "- END";
+       //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 MainWindowInputOthers::~MainWindowInputOthers()
@@ -78,7 +79,8 @@ QSO MainWindowInputOthers::getQSOData(QSO _qso)
 {
     QSO qso = _qso;
 
-    qso.setDXCC(getEntity());
+    qso.setDXCC(getEntity() % 1000);
+   //qDebug() << Q_FUNC_INFO << " - DXCC: " << qso.getDXCC();
     qso.setState(getState());
     //qso.setCounty()           //TODO: Related to entitySecDivComboBox when implemented
     qso.setIOTA(getIOTA());
@@ -87,6 +89,7 @@ QSO MainWindowInputOthers::getQSOData(QSO _qso)
     qso.setAge(getAge());
     qso.setDistance(getDistance());
     qso.setSIG(getSIG());
+    //qDebug() << Q_FUNC_INFO << " - AGE stored" << qso.getAge();
     qso.setSIG_INFO(getSIG_INFO());
     qso.setVUCCGrids(getVUCCGrids());
     qso.setWWFF_Ref(getWWFF_Ref());
@@ -97,6 +100,11 @@ QSO MainWindowInputOthers::getQSOData(QSO _qso)
 void MainWindowInputOthers::setQSOData(const QSO &_qso)
 {
     QSO qso(_qso);
+
+    int qrzEntity = world->getQRZARRLId(qso.getCall());
+    if (world->selectEntity(qrzEntity, qso.getDXCC()>0))
+        setEntity(qrzEntity);
+    else
     setEntity(qso.getDXCC());
     setPropMode(qso.getPropMode(), false);
     setSOTA(qso.getSOTA_REF());
@@ -116,7 +124,7 @@ void MainWindowInputOthers::createUI()
    //qDebug() << Q_FUNC_INFO ;
     logEvent (Q_FUNC_INFO, "Start", Debug);
 
-    entitiesList.clear();
+    //entitiesList.clear();
     propModeList.clear();
     adifValidTypes.clear();
     autoUpdating = false;
@@ -199,13 +207,7 @@ void MainWindowInputOthers::createUI()
     tabLayout->addWidget(keepPropCheckBox, 6, 2);
     //tabLayout->setSizeConstraint(QLayout::SetFixedSize);
     setLayout(tabLayout);
-    entitiesList.clear();
-    entitiesList.append( dataProxy->getEntitiesNames());
-    if (entitiesList.size()>1)
-    {
-        entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
-        entityNameComboBox->addItems(entitiesList);
-    }
+
    //qDebug() << Q_FUNC_INFO << ": Trying to add PropModes";
     propModeList = dataProxy->getPropModeList();
     if (propModeList.size()>1)
@@ -263,18 +265,19 @@ void MainWindowInputOthers::clear(bool _full)
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
+
+void MainWindowInputOthers::setEntitiesList()
 {
-      //qDebug() << Q_FUNC_INFO << ": " << QString::number(_qs.length());
+      //qDebug() << Q_FUNC_INFO << " - Start";
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    entitiesList.clear();
-    entitiesList << _qs;
-    if (entitiesList.size()>1)
-    {
-        entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
-        //entitiesList.prepend("00-Not Identified (000)");
-        entityNameComboBox->addItems(entitiesList);
-    }
+      QStringList entitiesList;
+      entitiesList.append( dataProxy->getEntitiesNames(false));
+      if (entitiesList.size()>1)
+      {
+          entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
+          entityNameComboBox->addItems(entitiesList);
+      }
+
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
@@ -302,7 +305,10 @@ QString MainWindowInputOthers::getEntityPrefix()
 {
     //qDebug() << Q_FUNC_INFO << ": " << (entityNameComboBox->currentText()).split('-').at(0);
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
-    return (entityNameComboBox->currentText()).split('-').at(0);
+    QString prefix = (entityNameComboBox->currentText()).split('-').at(0);
+    if (prefix.startsWith('*'))
+         prefix.remove(QChar('*'), Qt::CaseInsensitive);
+    return prefix;
     //return world->getQRZARRLId(pref);
 }
 
@@ -551,7 +557,7 @@ bool MainWindowInputOthers::setPOTA_REF(const QString &_op)
     if (!adif.isValidPOTA(_op))
         return false;
     pota_ref = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -571,7 +577,7 @@ bool MainWindowInputOthers::setSIG(const QString &_op)
     if (_op.length()<=0)
         return false;
     sig = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -591,7 +597,7 @@ bool MainWindowInputOthers::setSIG_INFO(const QString &_op)
     if (_op.length()<=0)
         return false;
     sig_info = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -612,14 +618,15 @@ bool MainWindowInputOthers::setWWFF_Ref(const QString &_op)
     if (!adif.isValidWWFF_Ref(_op))
         return false;
     wwff_ref = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    //qDebug() << Q_FUNC_INFO << ": " << wwff_ref;
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
 QString MainWindowInputOthers::getWWFF_Ref()
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << ": " << wwff_ref;
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
     return wwff_ref;
 }
@@ -673,7 +680,7 @@ QString MainWindowInputOthers::getUserADIFTypeComboBox()
     logEvent (Q_FUNC_INFO, "Start", Debug);
     int value = (((userDefinedADIFComboBox->currentText ()).split('-')).at(0)).toInt ();
     //qDebug() << Q_FUNC_INFO << ": " << QString::number(value);
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(value);
+
     switch (value)
     {
     case 1:
@@ -722,6 +729,7 @@ QString MainWindowInputOthers::getUserADIFValue()
 bool MainWindowInputOthers::setInitialADIFValues()
 {
     logEvent (Q_FUNC_INFO, "END-", Debug);
+    setEntitiesList();
     adifValidTypes  << "01-"    + tr("SOTA Ref")    << "02-" + tr ("Age")
                    << "03-"     + tr("Distance")    << "04-" + tr("POTA Ref")
                    << "05-"     + tr("SIG")         << "06-" + tr("SIG Info")
@@ -809,15 +817,15 @@ void MainWindowInputOthers::setEntity(const int _entity)
     }
   //qDebug() << Q_FUNC_INFO << " - 20" ;
     currentInt = _entity;
-    QString aux = QString::number(_entity);
+    QString num = QString::number(_entity);
     if (_entity > 1000)
     {
       //qDebug() << Q_FUNC_INFO << " - 30" ;
-        aux = (QString::number(_entity)).right(3);
+       // num = (QString::number(_entity)).right(3);
     }
   //qDebug() << Q_FUNC_INFO << " - 40" ;
 
-    int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
+    int indexC = entityNameComboBox->findText("(" + num + ")", Qt::MatchEndsWith);
     if (indexC != -1)
     {
         entityNameComboBox->setCurrentIndex(indexC);
@@ -827,7 +835,6 @@ void MainWindowInputOthers::setEntity(const int _entity)
       //qDebug() << Q_FUNC_INFO << " - Unable to find entity in the ComboBox";
     }
 
-
     setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_entity)) ;
     //qDebug() << Q_FUNC_INFO << " - 100" ;
     logEvent (Q_FUNC_INFO, "END", Debug);
@@ -857,11 +864,14 @@ void MainWindowInputOthers::setEntityAndPrefix(const int _entity, const QString
 
 
     Callsign entityCall(prefixFromEntityNumber);    // To check if the prefixFromEntity is the main or not (EA->main, AM-> nor main, it should be EA)
-    QString prefixForSubdivision = prefixFromEntityNumber;    
+    QString prefixForSubdivision = prefixFromEntityNumber;
 
+   //qDebug() << Q_FUNC_INFO << " - Before: hostPrefix:              " << hostPrefix;
+   //qDebug() << Q_FUNC_INFO << " - Before: prefixFromEntityNumber:  " << prefixFromEntityNumber;
      // Construct hostFullPrefix if hostPrefix is not the main prefix.
     if (hostPrefix != prefixFromEntityNumber)
     {
+       //qDebug() << Q_FUNC_INFO << " - Building: " << prefixFromEntityNumber;
         hostFullPrefix = prefixFromEntityNumber + QString::number(callsign.getHostAreaNumber());
     }
 
@@ -870,6 +880,7 @@ void MainWindowInputOthers::setEntityAndPrefix(const int _entity, const QString
   //qDebug() << Q_FUNC_INFO << "hostPrefix:                 " << hostPrefix;
   //qDebug() << Q_FUNC_INFO << "prefixFromEntityNumber:     " << prefixFromEntityNumber;
 
+// ea4k parece que falla para IT9
 
     if ((hostFullPrefix.isEmpty()) && (hostPrefix.isEmpty()))
         return;
@@ -917,7 +928,7 @@ void MainWindowInputOthers::setEntityAndPrefix(const int _entity, const QString
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
-void MainWindowInputOthers::slotUSerDefinedADIFComboBoxChanged()
+void MainWindowInputOthers::slotUserDefinedADIFComboBoxChanged()
 {
     //qDebug() << Q_FUNC_INFO << ": " << getUserADIFTypeComboBox ();
     logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -966,7 +977,7 @@ bool MainWindowInputOthers::setVUCCGrids(const QString &_op)
     if (checkVUCC_GRIDS(_op))
     {
         vucc_grids = _op;
-        slotUSerDefinedADIFComboBoxChanged();
+        slotUserDefinedADIFComboBoxChanged();
         logEvent (Q_FUNC_INFO, "END-1", Debug);
         return true;
     }
@@ -1026,7 +1037,7 @@ bool MainWindowInputOthers::setSOTA(const QString &_op)
     //qDebug() << Q_FUNC_INFO << ": " << _op;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     sota_ref = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -1043,7 +1054,7 @@ bool MainWindowInputOthers::setAge(const double _op)
     //qDebug() << Q_FUNC_INFO << ": " << _op;
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
     age = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -1051,6 +1062,7 @@ bool MainWindowInputOthers::setAge(const double _op)
 double MainWindowInputOthers::getAge()
 {
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
+    //qDebug() << Q_FUNC_INFO << ": " << age;
     return age;
 }
 
@@ -1059,7 +1071,7 @@ bool MainWindowInputOthers::setDistance(const double _op)
     //qDebug() << Q_FUNC_INFO << ": " << _op;
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
     distance = _op;
-    slotUSerDefinedADIFComboBoxChanged();
+    slotUserDefinedADIFComboBoxChanged();
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
@@ -1132,7 +1144,8 @@ void MainWindowInputOthers::slotShowAllCheckBoxChanged()
 void MainWindowInputOthers::slotEntityNameComboBoxChanged()
 {
     //qDebug() << Q_FUNC_INFO << entityNameComboBox->currentText();
-    QString prefix = ((entityNameComboBox->currentText()).split("-")).at(0);
+
+    QString prefix = getEntityPrefix();
     //qDebug() << Q_FUNC_INFO << " - " << prefix;
     int entity = world->getQRZARRLId(prefix);
     setEntityAndPrefix(entity, prefix);
