@@ -42,12 +42,12 @@ class MainWindowInputOthers : public QWidget
     friend class tst_MainWindowInputOthers;
 
 public:
-    MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent = nullptr);
+    MainWindowInputOthers(DataProxy_SQLite *dp, World *injectedWorld, QWidget *parent = nullptr);
     ~MainWindowInputOthers();
     void setDarkMode (const bool _dm);
     QSO getQSOData(QSO _qso);
     void setQSOData(const QSO &_qso);
-    void setEntitiesList(const QStringList _qs);
+    void setEntitiesList();
     void setEntity(const int _entity);               // Move the external call to setEntityAndPrefix
     int getEntity();
     QString getEntityPrefix();
@@ -105,7 +105,7 @@ signals:
 private slots:
     //void slotSetPropMode(const QString &_p); // To receive the signal from the SAT widget and set "SAT" propagation mode, of needed.
     void slotPropModeComboBoxChanged();
-    void slotUSerDefinedADIFComboBoxChanged();
+    void slotUserDefinedADIFComboBoxChanged();
     void slotSetCurrentUserData();
     void slotPrimarySubdivisionsComboBoxChanged();
     void slotShowAllCheckBoxChanged();
@@ -131,7 +131,7 @@ private:
     World *world;
     bool darkMode;
 
-    QStringList entitiesList, propModeList;
+    QStringList  propModeList; // entitiesList,
     //QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
     QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
     QLineEdit *iotaNumberLineEdit;
