@@ -34,14 +34,17 @@
 #include <QWidget>
 #include "../dataproxy_sqlite.h"
 #include "../utilities.h"
+#include "../qso.h"
 
 class MainWindowInputQSL : public QWidget
 {
     Q_OBJECT
+
 public:
     explicit MainWindowInputQSL(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainWindowInputQSL();
-
+    QSO getQSOData(QSO _qso);
+    void setQSOData(const QSO &_qso);
     QString getQSLRecStatus();
     QString getQSLSenStatus();
     QString getSentVia();
@@ -66,8 +69,8 @@ public:
 
 signals:
     void returnPressed();
-private slots:
 
+private slots:
     void slotQSLViaTextChanged();
     void slotQSLSentComboBoxChanged();
     void slotQSLRecvComboBoxChanged();
@@ -79,7 +82,6 @@ private slots:
     void slotLotwSentComboBoxChanged();
 */
 private:
-
     void createUI();
     void setDefaultData();
 
