@@ -1,3 +1,5 @@
+#ifndef KLOG_LOCATOR_H
+#define KLOG_LOCATOR_H
 /***************************************************************************
                           locator.h  -  description
                              -------------------
@@ -24,15 +26,12 @@
  *                                                                           *
  *****************************************************************************/
 
-#ifndef KLOG_LOCATOR_H
-#define KLOG_LOCATOR_H
+
 #include <math.h>
 #include <QString>
 #include <QRegularExpression>
 #include "klogdefinitions.h"
 
-
-
 const double PI = 3.141592654; //http://en.wikipedia.org/wiki/Pi
 const bool LATITUDE = false;
 const bool LONGITUDE = true;
@@ -41,13 +40,11 @@ const double RADIAN = 180.0/PI;
 const double DEG_TO_RAD = PI/180.0;
 const double KM_IN_A_MILE = 1.609344;
 
-
-
-class Locator{
-
+class Locator
+{
 public:
-
     Locator();
+    //Locator(const QString &tlocator, QObject *parent = nullptr);
     ~Locator();
 
     bool isValidLocator(const QString& tlocator);
@@ -75,8 +72,6 @@ private:
   //QChar theChar;
   //double my_lon, my_lat, other_lon, other_lat, beam, testNumb;
   //int ideg, imin, isec;
-
-
 };
 
 #endif
