@@ -26,6 +26,13 @@
 
 #include "logmodel.h"
 
+const QMap<QString, LogModel::ValidationFunc> LogModel::s_validationRules = {
+    { "my_dxcc", [](const QVariant &v) { bool ok; int dxcc = v.toInt(&ok); return (ok && (dxcc >= 0) && (dxcc <= 530)); } },
+    { "age", [](const QVariant &v) { bool ok; int age = v.toInt(&ok); return ok && age > 0.0 && age < 120.0; } },
+    { "ant_az", [](const QVariant &v) { bool ok; double az = v.toDouble(&ok); return ok && az >= 0.0 && az <= 360.0; } },
+    // ... add more column validators here ...
+};
+
 LogModel::LogModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTableModel(parent)
 {
      //qDebug() << Q_FUNC_INFO ;
@@ -36,11 +43,60 @@ LogModel::LogModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTableMod
     columns.clear();
     columns.append(dataProxy->filterValidFields(util->getDefaultLogFields()));
     setTable("log");
+    // Ensure unmatched foreign keys do NOT hide base rows (e.g., dxcc=0)
+
+    setJoinMode(QSqlRelationalTableModel::LeftJoin);
 
     setEditStrategy(QSqlTableModel::OnFieldChange);
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
+QVariant LogModel::data(const QModelIndex &index, int role) const
+{ // Used to check if the data to be shown in the logview table must or not be shown
+  // Depending on the data validation. Check: ValidationFunc above
+    //qDebug() << Q_FUNC_INFO;
+    if (role != Qt::DisplayRole)
+        return QSqlRelationalTableModel::data(index, role);
+
+    QString columnName = this->record().fieldName(index.column());
+
+    // Validation: optionally hide invalid values for some columns
+    auto it = s_validationRules.find(columnName);
+    if (it != s_validationRules.end()) {
+        QVariant raw = QSqlRelationalTableModel::data(index, role);
+        if (!it.value()(raw)) {
+            return QVariant(); // Hide invalid cell content
+        }
+    }
+
+    // Provide a friendly fallback for relational columns that don't resolve (e.g., dxcc=0 → no match in entity)
+    QVariant v = QSqlRelationalTableModel::data(index, role);
+
+// If this column has a relation and no display data could be resolved, return "Unknown"
+
+    // relation() is available on QSqlRelationalTableModel; check if this column is relational
+    // Note: even though fieldName is the base column ("dxcc"), the DisplayRole here is the related display column (e.g., entity.name)
+    if (!v.isValid() || (v.type() == QVariant::String && v.toString().isEmpty())) {
+        const QSqlRelation rel = relation(index.column());
+        if (rel.isValid()) {
+            // Specifically requested: show unknown for dxcc with no matching entity.
+            // You may extend this behavior to other relations (modeid, bandid) as needed.
+            if (columnName == "dxcc") {
+                return tr("Unknown");
+            }
+            else
+            {
+                // Generic fallback for any unresolved relation (optional):
+                // return tr("Unknown");
+                return tr("Unknown");
+            }
+
+        }
+    }
+
+    return v;
+}
+
 bool LogModel::createlogModel(const int _i)
 {
 /*
@@ -145,11 +201,11 @@ bool LogModel::setColumns(const QStringList &_columns)
          setRelation(nameCol, QSqlRelation("entity", "dxcc", "name"));
      }
 
-     if (_columns.contains("qso_complete"))
-     {
-         nameCol = rec.indexOf("qso_complete");
-         setRelation(nameCol, QSqlRelation("qso_complete_enumeration", "id", "shortname"));
-     }
+     //if (_columns.contains("qso_complete"))
+     //{
+     //    nameCol = rec.indexOf("qso_complete");
+     //    setRelation(nameCol, QSqlRelation("qso_complete_enumeration", "id", "shortname"));
+     //}
 
      nameCol = rec.indexOf("id");
      setSort(nameCol, Qt::AscendingOrder);
