@@ -138,11 +138,12 @@ class MainWindow : public  QMainWindow
     friend class tst_MainWindow;
 
 public:
-    MainWindow(DataProxy_SQLite *dp);
+    MainWindow(DataProxy_SQLite *dp, World *injectedWorld);
     ~MainWindow();
     void checkIfNewVersion();
     void recommendBackupIfNeeded();
     void init();
+    //void setPkgVersion(const QString &_pkgVersion);
     //void showNotWar();
 
 private slots:
@@ -194,9 +195,9 @@ private slots:
     void slotLogRefresh();
 
     void slotQSODelete(const int _id);
-    void slotQSOsDelete(QList<int> _id);
-    void slotQSOsExportToADIF(QList<int> _id);
-    void slotQRZcomUpload(QList<int> _id);
+    void slotQSOsDelete(QList<int> _qsos);
+    void slotQSOsExportToADIF(QList<int> _qsos);
+    void slotQRZcomUpload(QList<int> _qsos);
     void slotQRZCOMLogUpload();
     void slotElogQRZCOMDisable(const bool _b);
 
@@ -378,7 +379,7 @@ private:
     bool hamlibChangingMode;
     bool hamlibModeNotADIFSupported;
 
-    bool sendQSLByDefault;
+    //bool sendQSLByDefault;
     bool deleteAlwaysAdiFile;
 
     MapWindowWidget *mapWindow;
@@ -645,12 +646,12 @@ private:
     QString infoLabel1T, infoLabel2T;
 
     QString ctyDatFile, defaultADIFLogFile;
-    QString softwareVersion;
+    QString softwareVersion, pkgVersion;
     bool itIsANewversion;
     int dupeSlotInSeconds;
+    QString lotwSentDefault, qrzcomSentDefault, clublogSentDefault, eqslSentDefault;
+    QString stx, srx;
 
-    QString stx;
-    QString srx;
     QPalette palRed, palBlack; // To paint Text in red or black(normal)
     bool  alwaysADIF, needToSave, useDefaultLogFileName, upAndRunning, qrzSmallModDontCalculate, imperialSystem, sendQSLWhenRec, manageDxMarathon, completeWithPrevious, completedWithPreviousQTH, completedWithPreviousLocator, completedWithPreviousName, completedWithPreviousIOTA, completedWithPreviousQSLVia;
     // bool realTime, UTCTime;
