@@ -35,6 +35,7 @@
 #include "utilities.h"
 #include "klogdefinitions.h"
 #include "adif.h"
+#include "frequency.h"
 
 class QSO : public QObject
 {
@@ -60,10 +61,11 @@ public:
     void setModifying(const bool _mod);
     bool getModifying() const;
 
-    bool setData(const QString &_adifPair);
+    bool setData(const QString &_adifPair, bool _lotw = false);
     void clear();
     bool isValid();
     void setLoTWUpdating(bool _lotw);
+    bool getLoTWUpdating();
 
     bool setCall(const QString &_c);
     QString getCall() const;
@@ -234,8 +236,8 @@ public:
     QString getAddress() const;
     bool setAltitude(const double _c);
     double getAltitude() const;
-    bool setA_Index(const int _i);
-    int getA_Index() const;
+    bool setA_Index(const double _i);
+    double getA_Index() const;
     bool setAnt_az(const double _c);
     double getAnt_az() const;
     bool setAnt_el(const double _c);
@@ -250,8 +252,8 @@ public:
     QString getClass() const;
     bool setContinent(const QString &_c);
     QString getContinent() const;
-    bool setDistance(const double _i);
-    double getDistance() const;
+    bool setDistance(const double _i);          // In Km
+    double getDistance() const;                 // In Km
     bool setOwnerCallsign(const QString &_c);
     QString getOwnerCallsign() const;
     bool setEQ_Call(const QString &_c); // Contacted station owner
@@ -273,10 +275,17 @@ public:
 
     bool setK_Index(const int _i);
     int getK_Index() const;
+
+    bool setDateTimeOff(const QDateTime &_c);
+    QDateTime getDateTimeOff() const;
     bool setDateOff(const QDate &_c);
     QDate getDateOff() const;
     bool setTimeOff(const QTime &_c);
     QTime getTimeOff() const;
+
+
+
+
     bool setRig(const QString &_c);
     QString getRig() const;
     bool setCountry(const QString &_c);
@@ -417,9 +426,9 @@ public:
     //bool add();
     //bool modify(const int _qsoId);
     bool isComplete() const;
-    QString getADIF();
+    QString getADIF(ExportMode _em = ModeADIF);
     QString getBandNameFromFreq(const double _n); // Should be push out of this class
-
+    bool updateFromLoTW(const int _qsoId);        // It checks if the QSO is already in the log and updates just the LoTW fields, if needed.
 
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
@@ -428,9 +437,15 @@ signals:
 
 private:
     //QTime startT;
+    QString getADIFStandard();
+    QString getADIFLoTW();
+    QString getADIFClubLog();
+    QString getADIFeQSL();
+
+    void printQSO();
     bool isValidCall() const;
-    bool isValidBand() const;
-    bool isValidMode() const;
+    //bool isValidBand() const;
+    //bool isValidMode() const;
     bool isValidDateTime() const;
 
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
@@ -445,10 +460,15 @@ private:
     //enum QSOStatus {unknown, ATNO, needed, worked, confirmed, dupe};
     //DataBase *db;
 
+    // Functions to update a QSO after downloading LoTW
 
-    int qsoId, logId, dxcc, a_index, k_index, cqz, fists, fists_cc, my_fists, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
+    int findIdFromQSO(const QString &_qrz, const QDateTime &_datetime, const int _band, const int _mode);
+
+
+    int qsoId, logId, dxcc, k_index, cqz, fists, fists_cc, my_fists, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
     int ten_ten, sfi;
-    double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, distance, altitude, my_altitude;
+    double pwr_rx, pwr_tx, age, ant_el, ant_az, distance, altitude, my_altitude, a_index;
+    Frequency freq_tx, freq_rx;
 
     QString satName, satMode, callsign, stationCallsign, operatorCall, propMode, band, band_rx, mode, gridsquare, my_gridsquare, gridsquare_ext, my_gridsquare_ext, qth, name, RST_tx, RST_rx;
     QString qsl_rcvd, qsl_sent, qslSenVia, qslRecVia, qslVia, check, clase;
@@ -463,10 +483,11 @@ private:
     QString iota, ownerCall, latitude, longitude, ms_shower, notes, prefix, precedence, public_key, qslmsg, region, sig, sig_info, skcc, srx_string, stx_string, state, submode;
     QString my_city, my_county, my_country, my_iota, my_latitude, my_longitude, my_name, my_postal_code, my_sig, my_sig_info, my_state, my_street, my_usaca_counties, my_wwff_ref;
 
-    QTime qso_time_off;
+    //QTime qso_time_off;
     QDateTime qso_dateTime;
+    QDateTime qso_dateTime_off;
 
-    QDate QSLRDate, QSLSDate, QSLLoTWRDate, QSLLoTWSDate, qso_date_off;
+    QDate QSLRDate, QSLSDate, QSLLoTWRDate, QSLLoTWSDate;//, qso_date_off;
     QDate eQSLRDate, eQSLSDate, clublogQSOUpdateDate, hrdlogUploadDate;
     QDate hamlogeuUpdateDate, hamqthUpdateDate;
 
@@ -492,7 +513,7 @@ private:
     bool setAnt_az(const QString &data);
     bool setAnt_el(const QString &data);
     bool setCQZone(const QString &data);
-    bool setDistance(const QString &data);
+    bool setDistance(const QString &data);      // In Km
     bool setDXCC(const QString &data);
     bool setFists(const QString &data);
     bool setFistsCC(const QString &data);
@@ -538,9 +559,11 @@ private:
     bool setTimeOff(const QString& data);
     bool setTimeOn(const QString& data);
 
-    bool setLoTWQSLRDate2(const QString& data);
-    bool setLoTWQSLSDate1(const QString& data);
-    bool setLoTWQSLSDate2(const QString& data);
+    void clearQSLDateIfNeeded();            // Prevents a date when not ADIF compatible
+
+    //KLOG_DEPRECATED bool setLoTWQSLRDate2(const QString& data);
+    //KLOG_DEPRECATED bool setLoTWQSLSDate1(const QString& data);
+    //KLOG_DEPRECATED bool setLoTWQSLSDate2(const QString& data);
 
     int getLastInsertedQSO();   // just a query to get the latest inserted QSO
 };
