@@ -31,7 +31,7 @@
 
 SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
 {
-     //qDebug() << "SetupPageELog::SetupPageELog";
+     //qDebug() << Q_FUNC_INFO " - Start";
     util = new Utilities(Q_FUNC_INFO);
 
     palRed.setColor(QPalette::Text, Qt::red);
@@ -42,13 +42,15 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     clubLogAppPasswordLineEdit = new QLineEdit;
     clubLogPasswordLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
     clubLogAppPasswordLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
-
+    clubLogSentDefaultComboBox = new QComboBox;
+    clubLogSentDefaultLabel = new QLabel(tr("Default"));
     clubLogPasswordLabel = new QLabel(tr("ClubLog password"));
     clubLogAppPasswordLabel = new QLabel(tr("ClubLog App password"));
     clubLogEmailLabel = new QLabel(tr("ClubLog email"));
     clubLogAppPasswordLabel->setBuddy (clubLogAppPasswordLineEdit);
     clubLogPasswordLabel->setBuddy(clubLogPasswordLineEdit);
     clubLogEmailLabel->setBuddy(clubLogEmailLineEdit);
+    clubLogSentDefaultLabel->setBuddy(clubLogSentDefaultComboBox);
 
     clubLogEmailLineEdit->setToolTip(tr("Enter the email you used to register in ClubLog."));
     clubLogPasswordLineEdit->setToolTip(tr("Enter your password ClubLog here. Warning: The password will be save on clear in the KLog config file!! (If you don't want to enter the password, KLog will ask you when it is needed.)"));
@@ -62,7 +64,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     clubLogActiveCheckBox = new QCheckBox(tr("Activate ClubLog"), this);
     clubLogSendInRealTimeCheckBox->setToolTip(tr("Send each QSO to ClubLog in real time, as they are added (or modified) in KLog."));
     clubLogActiveCheckBox->setToolTip(tr("Starts the ClubLog support in KLog."));
-     //qDebug() << "SetupPageELog::SetupPageELog - 00010";
+     //qDebug() << Q_FUNC_INFO << " -   00010";
     eQSLUserLineEdit = new QLineEdit;
     eQSLPasswordLineEdit = new QLineEdit;
     eQSLPasswordLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
@@ -74,9 +76,13 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     eQSLpasswordLabel = new QLabel(tr("eQSL.cc password"));
     eQSLemailLabel = new QLabel(tr("eQSL.cc user"));
 
+    eQSLSentDefaultComboBox = new QComboBox;
+    eQSLSentDefaultLabel = new QLabel("Default");
+    eQSLSentDefaultLabel->setBuddy(eQSLSentDefaultComboBox);
+
     clubLogGroup = new QGroupBox (tr("ClubLog"));
     eQSLccGroup = new QGroupBox (tr("eQSL.cc"));
-     //qDebug() << "SetupPageELog::SetupPageELog - 00020";
+     //qDebug() << Q_FUNC_INFO << " -   00020";
     QGridLayout *cl1layout = new QGridLayout;
     cl1layout->addWidget(clubLogEmailLabel, 0, 0);
     cl1layout->addWidget(clubLogPasswordLabel, 1, 0);
@@ -85,27 +91,52 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     cl1layout->addWidget(clubLogPasswordLineEdit, 1, 1);
     cl1layout->addWidget(clubLogAppPasswordLineEdit, 2, 1);
 
+    clubLogSentDefaultLabel->setToolTip(tr("Select the default option for new QSOs in Clublog"));
+    clubLogSentDefaultComboBox->setToolTip(tr("Select the default option for new QSOs in Clublog"));
+    QHBoxLayout *clubLogSentDefaultLayout = new QHBoxLayout;
+    clubLogSentDefaultLayout->addWidget(clubLogSentDefaultLabel);
+    clubLogSentDefaultLayout->addWidget(clubLogSentDefaultComboBox);
+
+    QHBoxLayout *clubLogTopLineLayout = new QHBoxLayout;
+    clubLogTopLineLayout->addWidget(clubLogActiveCheckBox);
+    clubLogTopLineLayout->addLayout(clubLogSentDefaultLayout);
+
 
     QVBoxLayout *cl2layout = new QVBoxLayout;
-    cl2layout->addWidget(clubLogActiveCheckBox);
-    //cl2layout->addWidget(warningLabel);
+    //cl2layout->addWidget(clubLogActiveCheckBox);
+    cl2layout->addLayout(clubLogTopLineLayout);
     cl2layout->addLayout(cl1layout);
     cl2layout->addWidget(clubLogSendInRealTimeCheckBox);
     clubLogGroup->setLayout(cl2layout);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00030";
+
+
+    //qDebug() << Q_FUNC_INFO << " -   00030";
     QGridLayout *e1layout = new QGridLayout;
     e1layout->addWidget(eQSLemailLabel, 0, 0);
     e1layout->addWidget(eQSLpasswordLabel, 1, 0);
     e1layout->addWidget(eQSLUserLineEdit, 0, 1);
     e1layout->addWidget(eQSLPasswordLineEdit, 1, 1);
 
+    QHBoxLayout *eQSLSentDefaultLayout = new QHBoxLayout;
+    eQSLSentDefaultLayout->addWidget(eQSLSentDefaultLabel);
+    eQSLSentDefaultLayout->addWidget(eQSLSentDefaultComboBox);
+
+    eQSLSentDefaultLabel->setToolTip(tr("Select the default option for new QSOs in eQSL"));
+    eQSLSentDefaultComboBox->setToolTip(tr("Select the default option for new QSOs in eQSL"));
+    QHBoxLayout *eQSLTopLineLayout = new QHBoxLayout;
+    eQSLTopLineLayout->addWidget(eQSLActiveCheckBox);
+    eQSLTopLineLayout->addLayout(eQSLSentDefaultLayout);
+
     QVBoxLayout *e2layout = new QVBoxLayout;
-    e2layout->addWidget(eQSLActiveCheckBox);
+    e2layout->addLayout(eQSLTopLineLayout);
     e2layout->addLayout(e1layout);
     //e2layout->addWidget(eQSLSendInRealTimeCheckBox);
     eQSLccGroup->setLayout(e2layout);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00040";
+     //qDebug() << Q_FUNC_INFO << " -   00040";
     QRZCOMGroup = new QGroupBox (tr("QRZ.com"));
+    QRZCOMSentDefaultComboBox = new QComboBox;
+    QRZCOMSentDefaultLabel = new QLabel("Default");
+    QRZCOMSentDefaultLabel->setBuddy(QRZCOMSentDefaultComboBox);
 
     QRZCOMUserLineEdit = new QLineEdit;
     QRZCOMUserLineEdit->setToolTip(tr("Enter the user of your QRZ.com account. You need to be subscribed to QRZ.com to use this service."));
@@ -120,7 +151,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     QRZCOMActiveCheckBox = new QCheckBox(tr("Activate QRZ.com"), this);
     QRZCOMAutoCheckCheckBox = new QCheckBox(tr("Check automatically"), this);
     QRZCOMAutoCheckCheckBox->setToolTip(tr("Check in Qrz.com all Calls as they are entered"));
-     //qDebug() << "SetupPageELog::SetupPageELog - 00050";
+     //qDebug() << Q_FUNC_INFO << " -   00050";
     QRZCOMSubscriberCheckBox = new QCheckBox(tr("Paying Subscriber"), this);
     QRZCOMSubscriberCheckBox->setToolTip(tr("Check it if you are paying for a qrz.com subscription"));
 
@@ -136,24 +167,36 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     q1layout->addWidget(QRZCOMPasswordLineEdit, 1, 1);
     q1layout->addWidget(QRZCOMSubscriberCheckBox,0,2);
 
+    QHBoxLayout *qrzcomActive = new QHBoxLayout;
+    qrzcomActive->addWidget(QRZCOMActiveCheckBox);
+    qrzcomActive->addWidget(QRZCOMSubscriberCheckBox);
+
+    QRZCOMSentDefaultLabel->setToolTip(tr("Select the default option for new QSOs in QRZ.com"));
+    QRZCOMSentDefaultComboBox->setToolTip(tr("Select the default option for new QSOs in QRZ.com"));
+    QHBoxLayout *QRZCOMSentDefaultLayout = new QHBoxLayout;
+    QRZCOMSentDefaultLayout->addWidget(QRZCOMSentDefaultLabel);
+    QRZCOMSentDefaultLayout->addWidget(QRZCOMSentDefaultComboBox);
+    QHBoxLayout *QRZCOMTopLineLayout = new QHBoxLayout;
+    QRZCOMTopLineLayout->addLayout(qrzcomActive);
+    QRZCOMTopLineLayout->addLayout(QRZCOMSentDefaultLayout);
+
+
     QHBoxLayout *qrzcomKeyLayout = new QHBoxLayout;
     qrzcomKeyLayout->addWidget(QRZLogBookKeyLabel);
     qrzcomKeyLayout->addWidget(QRZCOMLogBookKEYLineEdit);
 
-    QHBoxLayout *qrzcomActive = new QHBoxLayout;
-    qrzcomActive->addWidget(QRZCOMActiveCheckBox);
-    //qrzcomActive->addWidget(QRZCOMSubscriberCheckBox);
 
-     //qDebug() << "SetupPageELog::SetupPageELog - 00070";
+     //qDebug() << Q_FUNC_INFO << " -   00070";
     QVBoxLayout *qrzLayout = new QVBoxLayout;
-    qrzLayout->addLayout(qrzcomActive);
+    qrzLayout->addLayout(QRZCOMTopLineLayout);
+    //qrzLayout->addLayout(qrzcomActive);
     qrzLayout->addLayout(q1layout);
     qrzLayout->addWidget(QRZCOMAutoCheckCheckBox);
     qrzLayout->addLayout(qrzcomKeyLayout);
 
     QRZCOMGroup->setLayout(qrzLayout);
 
-     //qDebug() << "SetupPageELog::SetupPageELog - 00080";
+     //qDebug() << Q_FUNC_INFO << " -   00080";
 
     lotwGroup = new QGroupBox (tr("LoTW"));
     lotwUpGroup = new QGroupBox (tr("Upload"));
@@ -161,6 +204,9 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
 
     lotwUserLineEdit = new QLineEdit;
     lotwUserLineEdit->setValidator(new QRegularExpressionValidator(rx, this));
+    lotwSentDefaultComboBox = new QComboBox;
+    lotwSentDefaultLabel = new QLabel("Default");
+    lotwSentDefaultLabel->setBuddy(lotwSentDefaultComboBox);
 
     lotwPasswordLineEdit = new QLineEdit;
     lotwPasswordLineEdit->setEchoMode(QLineEdit::PasswordEchoOnEdit);
@@ -175,13 +221,22 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     lotwTQSLPathLineEdit->setToolTip(tr("Path to the TQSL software."));
     lotwSearchTQSLPushButton->setToolTip(tr("Enable the LoTW integration with TQSL. You will need to have TQSL installed"));
 
+    lotwSentDefaultLabel->setToolTip(tr("Select the default option for new QSOs in LoTW"));
+    lotwSentDefaultComboBox->setToolTip(tr("Select the default option for new QSOs in LoTW"));
+    QHBoxLayout *lotwSentDefaultLayout = new QHBoxLayout;
+    lotwSentDefaultLayout->addWidget(lotwSentDefaultLabel);
+    lotwSentDefaultLayout->addWidget(lotwSentDefaultComboBox);
+    QHBoxLayout *lotwTopLineLayout = new QHBoxLayout;
+    lotwTopLineLayout->addWidget(lotwUseTQSLCheckBox);
+    lotwTopLineLayout->addLayout(lotwSentDefaultLayout);
+
     QHBoxLayout *l1layout = new QHBoxLayout;
     l1layout->addWidget(lotwTQSLPathLineEdit);
     l1layout->addWidget(lotwSearchTQSLPushButton);
     //lotwUpGroup->setLayout(l1layout);
 
     QVBoxLayout *l2layout = new QVBoxLayout;
-    l2layout->addWidget(lotwUseTQSLCheckBox);
+    l2layout->addLayout(lotwTopLineLayout);
     l2layout->addLayout(l1layout);
     lotwUpGroup->setLayout(l2layout);
 
@@ -191,26 +246,26 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     l3layout->addWidget(lotwUserLineEdit, 0, 1);
     l3layout->addWidget(lotwPasswordLineEdit, 1, 1);
     lotwDownGroup->setLayout(l3layout);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00100";
+     //qDebug() << Q_FUNC_INFO << " -   00100";
     QVBoxLayout *llayout = new QVBoxLayout;
     //llayout->addLayout(l2layout);
     llayout->addWidget(lotwUpGroup);
     llayout->addWidget(lotwDownGroup);
     lotwGroup->setLayout(llayout);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00110";
+     //qDebug() << Q_FUNC_INFO << " -   00110";
     QVBoxLayout *v1layout = new QVBoxLayout;
     v1layout->addWidget(clubLogGroup);
     v1layout->addWidget(eQSLccGroup);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00120";
+     //qDebug() << Q_FUNC_INFO << " -   00120";
     QVBoxLayout *v2layout = new QVBoxLayout;
     v2layout->addWidget(QRZCOMGroup);
     v2layout->addWidget(lotwGroup);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00130";
+     //qDebug() << Q_FUNC_INFO << " -   00130";
     QHBoxLayout *mlayout = new QHBoxLayout;
     mlayout->addLayout(v1layout);
     mlayout->addLayout(v2layout);
     setLayout(mlayout);
-     //qDebug() << "SetupPageELog::SetupPageELog - 00140";
+     //qDebug() << Q_FUNC_INFO << " -   00140";
     connect(clubLogActiveCheckBox, SIGNAL(toggled(bool) ), this, SLOT(slotClubLogActive(bool)));
 
     connect(clubLogPasswordLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
@@ -221,13 +276,13 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     connect(eQSLPasswordLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(eQSLActiveCheckBox, SIGNAL(toggled(bool) ), this, SLOT(slotEQSLActive(bool)));
     connect(eQSLUserLineEdit, SIGNAL(textChanged(QString)), this, SLOT(sloteQSLCallTextChanged() ) );
-     //qDebug() << "SetupPageELog::SetupPageELog - 00150";
+     //qDebug() << Q_FUNC_INFO << " -   00150";
     connect(QRZCOMActiveCheckBox, SIGNAL(toggled(bool) ), this, SLOT(slotQRZCOMActive(bool)));
     //connect(QRZCOMAutoCheckCheckBox, SIGNAL(toggled(bool) ), this, SLOT(slotQRZCOMAuto(bool)));
     connect(QRZCOMUserLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(QRZCOMUserLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotQRZCallTextChanged() ) );
     connect(QRZCOMPasswordLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
-     //qDebug() << "SetupPageELog::SetupPageELog - 00160";
+     //qDebug() << Q_FUNC_INFO << " -   00160";
 
     connect(lotwUserLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
     connect(lotwPasswordLineEdit, SIGNAL(returnPressed()), this, SLOT(slotEnterKeyPressed() ) );
@@ -239,7 +294,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     connect(clubLogEmailLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotClubLogEmailDefineColor() ) );
     connect(lotwUserLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotLoTWEmailDefineColor() ) );
 
-     //qDebug() << "SetupPageELog::SetupPageELog - 00150";
+     //qDebug() << Q_FUNC_INFO << " -   00150";
     setDefaults();
     slotClubLogActive(false);
     setLoTWActive(false);
@@ -247,7 +302,7 @@ SetupPageELog::SetupPageELog(QWidget *parent) : QWidget(parent)
     slotEQSLActive(false);
     slotQRZCOMActive(false);
 
-     //qDebug() << "SetupPageELog::SetupPageELog - END";
+     //qDebug() << Q_FUNC_INFO << " -   END";
 }
 
 SetupPageELog::~SetupPageELog()
@@ -255,38 +310,98 @@ SetupPageELog::~SetupPageELog()
     delete(util);
 }
 
+
+void SetupPageELog::setDefaultLoTW()
+{
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    Adif adif(Q_FUNC_INFO);
+    lotwSentDefaultComboBox->addItems(adif.getQSLSentStatus());
+    //qDebug() << Q_FUNC_INFO << " - Current-1: " << lotwSentDefaultComboBox->currentText();
+    int index = lotwSentDefaultComboBox->findText("Q", Qt::MatchFixedString);
+    lotwSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : 0);
+   //qDebug() << Q_FUNC_INFO << " - Current-2: " << lotwSentDefaultComboBox->currentText();
+
+
+    lotwPasswordLineEdit->clear ();
+    lotwUserLineEdit->clear ();
+    lotwPasswordLineEdit->clear ();
+   //qDebug() << Q_FUNC_INFO << " -   ";
+}
+
+void SetupPageELog::setDefaultClubLog()
+{
+    Adif adif(Q_FUNC_INFO);
+    clubLogSentDefaultComboBox->addItems(adif.getQSOUploadStatus());
+    int index = clubLogSentDefaultComboBox->findText("M", Qt::MatchFixedString);
+    clubLogSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : 0);
+
+    clubLogActiveCheckBox->setChecked (false);
+    clubLogSendInRealTimeCheckBox->setChecked (false);
+    clubLogEmailLineEdit->clear ();
+    clubLogPasswordLineEdit->clear();
+    clubLogAppPasswordLineEdit->clear();
+}
+
+void SetupPageELog::setDefaultEQSL()
+{
+    Adif adif(Q_FUNC_INFO);
+    eQSLSentDefaultComboBox->addItems(adif.getQSLSentStatus());
+    int index = eQSLSentDefaultComboBox->findText("Q", Qt::MatchFixedString);
+    eQSLSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : 0);
+    eQSLActiveCheckBox->setChecked(false);
+    eQSLPasswordLineEdit->clear();
+    eQSLUserLineEdit->clear();
+}
+
+void SetupPageELog::setDefaultQRZCOM()
+{
+    Adif adif(Q_FUNC_INFO);
+    QRZCOMSentDefaultComboBox->addItems(adif.getQSOUploadStatus());
+    int index = QRZCOMSentDefaultComboBox->findText("M", Qt::MatchFixedString);
+    QRZCOMSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : 0);
+
+    QRZCOMActiveCheckBox->setChecked (false);
+    QRZCOMAutoCheckCheckBox->setChecked (false);
+
+    QRZCOMPasswordLineEdit->clear ();
+    QRZCOMUserLineEdit->clear();
+    QRZCOMLogBookKEYLineEdit->clear ();
+}
+
+
+
 void SetupPageELog::slotQRZCallTextChanged()
 {
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged";
+    //qDebug() << Q_FUNC_INFO << " -  ";
     int cursor = QRZCOMUserLineEdit->cursorPosition();
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-1";
+    //qDebug() << Q_FUNC_INFO << " -  -1";
 
     QString aux = util->getClearSQLi (QRZCOMUserLineEdit->text());
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-2";
+    //qDebug() << Q_FUNC_INFO << " -  -2";
 
     Callsign callsign(aux);
     if (callsign.isValid())
     {
-        //qDebug() << "SetupPageELog::slotQRZCallTextChanged-2.1";
+        //qDebug() << Q_FUNC_INFO << " -  -2.1";
         QRZCOMUserLineEdit->setPalette(palBlack);
     }
     else
     {
-        //qDebug() << "SetupPageELog::slotQRZCallTextChanged-2.2";
+        //qDebug() << Q_FUNC_INFO << " -  -2.2";
          QRZCOMUserLineEdit->setPalette(palRed);
     }
 
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-3";
+    //qDebug() << Q_FUNC_INFO << " -  -3";
     QRZCOMUserLineEdit->setText(aux.toUpper());
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged-4";
+    //qDebug() << Q_FUNC_INFO << " -  -4";
     QRZCOMUserLineEdit->setCursorPosition(cursor);
 
-    //qDebug() << "SetupPageELog::slotQRZCallTextChanged - END";
+    //qDebug() << Q_FUNC_INFO << " -   - END";
 }
 
 void SetupPageELog::sloteQSLCallTextChanged()
 {
-    //qDebug() << "SetupPageELog::sloteQSLCallTextChanged";
+    //qDebug() << Q_FUNC_INFO << " - Start";
     int cursor = eQSLUserLineEdit->cursorPosition();
 
     QString aux = util->getClearSQLi (eQSLUserLineEdit->text());
@@ -303,12 +418,12 @@ void SetupPageELog::sloteQSLCallTextChanged()
 
     eQSLUserLineEdit->setText(aux.toUpper());
     eQSLUserLineEdit->setCursorPosition(cursor);
-    //qDebug() << "SetupPageELog::sloteQSLCallTextChanged - END";
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void SetupPageELog::slotClubLogEmailDefineColor()
 {
-    //qDebug() << "SetupPageELog::slotClubLogEmailDefineColor";
+    //qDebug() << Q_FUNC_INFO << " - Start"
     if(!clubLogEmailLineEdit->hasAcceptableInput())
         clubLogEmailLineEdit->setStyleSheet("QLineEdit { color: red;}");
     else
@@ -336,28 +451,14 @@ void SetupPageELog::slotLoTWEmailDefineColor()
 
 void SetupPageELog::setDefaults()
 {
-     //qDebug() << "SetupPageELog::setDefaults()";
-    QRZCOMActiveCheckBox->setChecked (false);
-    QRZCOMAutoCheckCheckBox->setChecked (false);
+     //qDebug() << Q_FUNC_INFO << " - Start"
 
-    QRZCOMPasswordLineEdit->clear ();
-    QRZCOMUserLineEdit->clear();
-    QRZCOMLogBookKEYLineEdit->clear ();
+    setDefaultClubLog();
+    setDefaultEQSL();
+    setDefaultLoTW();
+    setDefaultQRZCOM();
 
-    clubLogActiveCheckBox->setChecked (false);
-    clubLogSendInRealTimeCheckBox->setChecked (false);
-    clubLogEmailLineEdit->clear ();
-    clubLogPasswordLineEdit->clear();
-    clubLogAppPasswordLineEdit->clear();
-
-    eQSLActiveCheckBox->setChecked(false);
-    eQSLPasswordLineEdit->clear();
-    eQSLUserLineEdit->clear();
-
-    lotwPasswordLineEdit->clear ();
-    lotwUserLineEdit->clear ();
-    lotwPasswordLineEdit->clear ();
-     //qDebug() << "SetupPageELog::setDefaults() - END";
+     //qDebug() << Q_FUNC_INFO << " - END"
 }
 
 
@@ -369,7 +470,7 @@ void SetupPageELog::setClubLogActive(const bool &_b)
 
 void SetupPageELog::slotClubLogActive(const bool _s)
 {
-     //qDebug() << "SetupPageELog::slotClubLogActive: " << util->boolToQString(_s);
+     //qDebug() << Q_FUNC_INFO << " - " << util->boolToQString(_s);
     clubLogEmailLabel->setEnabled(_s);
     clubLogPasswordLabel->setEnabled(_s);
     clubLogEmailLineEdit->setEnabled(_s);
@@ -386,7 +487,7 @@ void SetupPageELog::slotClubLogActive(const bool _s)
 
 void SetupPageELog::slotEQSLActive(const bool _s)
 {
-     //qDebug() << "SetupPageELog::slotEQSLActive: "  << util->boolToQString(_s);
+     //qDebug() << Q_FUNC_INFO << " - "  << util->boolToQString(_s);
     eQSLemailLabel->setEnabled(_s);
     eQSLpasswordLabel->setEnabled(_s);
     eQSLUserLineEdit->setEnabled(_s);
@@ -395,7 +496,7 @@ void SetupPageELog::slotEQSLActive(const bool _s)
 
 void SetupPageELog::slotTQSLActive(const bool _s)
 {
-     //qDebug() << "SetupPageELog::slotTQSLActive: " << util->boolToQString(_s);
+     //qDebug() << Q_FUNC_INFO << " - " << util->boolToQString(_s);
     setLoTWActive(_s);
 }
 
@@ -413,7 +514,7 @@ void SetupPageELog::setLoTWActive(const bool &_s)
 
 void SetupPageELog::slotSelectTQSLClicked()
 {
-       //qDebug() << "SetupPageELogr::slotSelectTQSLClicked: " << QStandardPaths::ApplicationsLocation;
+       //qDebug() << Q_FUNC_INFO << " - " << QStandardPaths::ApplicationsLocation;
     QString appsDir= util->getTQSLsPath();
     //QString proposedName = util->getTQSLsFileName();
 
@@ -431,11 +532,11 @@ void SetupPageELog::slotSelectTQSLClicked()
     tqslFile.clear();
     tqslFile = QFileDialog::getOpenFileName(this, tr("Select File"), appsDir, filter);
 
-    if (tqslFile.length()>0)
+    if (!tqslFile.isEmpty())
     {
         lotwTQSLPathLineEdit->setText(tqslFile);
     }
-        //qDebug() << "SetupPageELogr::slotSelectTQSLClicked - END";
+        //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void SetupPageELog::slotPathLineEditChanged(const QString &_q)
@@ -462,23 +563,23 @@ void SetupPageELog::slotEnterKeyPressed()
 
 void SetupPageELog::setQRZCOMActive(const bool _s)
 {
-     //qDebug() << "SetupPageELog::setQRZCOMActive ";
+     //qDebug() << Q_FUNC_INFO << " - Start";
     QRZCOMActiveCheckBox->setChecked(_s);
     QRZCOMAutoCheckCheckBox->setEnabled(_s);
 }
 
 void SetupPageELog::slotQRZCOMActive(bool _s)
 {
-     //qDebug() << "SetupPageELog::slotQRZCOMActive: "  << util->boolToQString(_s);
+     //qDebug() << Q_FUNC_INFO << " - "  << util->boolToQString(_s);
     QRZCOMUserLabel->setEnabled(_s);
-     //qDebug() << "SetupPageELog::slotQRZCOMActive - 1";
+     //qDebug() << Q_FUNC_INFO << " -   1";
     QRZCOMUserLineEdit->setEnabled(_s);
-     //qDebug() << "SetupPageELog::slotQRZCOMActive - 2";
+     //qDebug() << Q_FUNC_INFO << " -   2";
     QRZCOMPasswordLabel->setEnabled(_s);
-     //qDebug() << "SetupPageELog::slotQRZCOMActive - 3";
+     //qDebug() << Q_FUNC_INFO << " -   3";
     QRZCOMPasswordLineEdit->setEnabled(_s);
     QRZCOMAutoCheckCheckBox->setEnabled(_s);
-     //qDebug() << "SetupPageELog::slotQRZCOMActive - END";
+     //qDebug() << Q_FUNC_INFO << " -   END";
     //if (!QRZCOMActiveCheckBox->isChecked())
     //{
     //    QRZCOMAutoCheckCheckBox->setChecked(false);
@@ -534,12 +635,14 @@ void SetupPageELog::saveSettings()
     settings.setValue ("ClubLogEmail", clubLogEmailLineEdit->text ());
     settings.setValue ("ClubLogPass", clubLogPasswordLineEdit->text());
     settings.setValue ("ClubLogAppPass", clubLogAppPasswordLineEdit->text());
+    settings.setValue ("ClubLogSentDefault", clubLogSentDefaultComboBox->currentText());
     settings.endGroup ();
 
     settings.beginGroup ("eQSL");
     settings.setValue ("eQSLActive", QVariant((eQSLActiveCheckBox->isChecked())));
     settings.setValue ("eQSLCall", eQSLUserLineEdit->text ());
     settings.setValue ("eQSLPass", eQSLPasswordLineEdit->text());
+    settings.setValue ("eQSLSentDefault", eQSLSentDefaultComboBox->currentText());
     settings.endGroup ();
 
     settings.beginGroup ("QRZcom");
@@ -549,6 +652,7 @@ void SetupPageELog::saveSettings()
     settings.setValue ("QRZcomSubscriber", QVariant((QRZCOMSubscriberCheckBox->isChecked())));
     settings.setValue ("QRZcomAuto", QVariant((QRZCOMAutoCheckCheckBox->isChecked())));
     settings.setValue ("QRZcomLogBookKey", QRZCOMLogBookKEYLineEdit->text ());
+    settings.setValue ("QRZcomSentDefault", QRZCOMSentDefaultComboBox->currentText());
     settings.endGroup ();
 
     settings.beginGroup ("LoTW");
@@ -556,11 +660,13 @@ void SetupPageELog::saveSettings()
     settings.setValue ("LoTWPath", lotwTQSLPathLineEdit->text());
     settings.setValue ("LoTWUser", lotwUserLineEdit->text());
     settings.setValue ("LoTWPass", lotwPasswordLineEdit->text());
+    settings.setValue ("LoTWSentDefault", lotwSentDefaultComboBox->currentText());
     settings.endGroup ();
 }
 
 void SetupPageELog::loadSettings()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QSettings settings(util->getCfgFile (), QSettings::IniFormat);
     settings.beginGroup ("ClubLog");
     clubLogActiveCheckBox->setChecked (settings.value("ClubLogActive").toBool ());
@@ -569,28 +675,41 @@ void SetupPageELog::loadSettings()
     clubLogEmailLineEdit->setText (settings.value("ClubLogEmail").toString ());
     clubLogPasswordLineEdit->setText (settings.value("ClubLogPass").toString ());
     clubLogAppPasswordLineEdit->setText (settings.value("ClubLogAppPass").toString ());
+    int indexBackup = clubLogSentDefaultComboBox->findText("M", Qt::MatchFixedString);
+    int index = clubLogSentDefaultComboBox->findText(settings.value("ClubLogSentDefault").toString(), Qt::MatchFixedString);
+    clubLogSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : indexBackup);
     settings.endGroup ();
 
     settings.beginGroup ("eQSL");
-    eQSLActiveCheckBox->setChecked (settings.value("eQSLActive").toBool ());
+    eQSLActiveCheckBox->setChecked (settings.value("eQSLActive", false).toBool ());
     eQSLUserLineEdit->setText (settings.value("eQSLCall").toString ());
     eQSLPasswordLineEdit->setText (settings.value("eQSLPass").toString ());
+    indexBackup = eQSLSentDefaultComboBox->findText("Q", Qt::MatchFixedString);
+    index = eQSLSentDefaultComboBox->findText(settings.value("eQSLSentDefault", "Q").toString(), Qt::MatchFixedString);
+    eQSLSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : indexBackup);
+
     settings.endGroup ();
 
     settings.beginGroup ("QRZcom");
-    QRZCOMActiveCheckBox->setChecked (settings.value("QRZcomActive").toBool ());
+    QRZCOMActiveCheckBox->setChecked (settings.value("QRZcomActive", false).toBool ());
     QRZCOMSubscriberCheckBox->setChecked (settings.value("QRZcomSubscriber").toBool ());
-    QRZCOMAutoCheckCheckBox->setChecked (settings.value("QRZcomAuto").toBool ());
+    QRZCOMAutoCheckCheckBox->setChecked (settings.value("QRZcomAuto", false).toBool ());
     QRZCOMUserLineEdit->setText (settings.value("QRZcomUser").toString ());
     QRZCOMPasswordLineEdit->setText (settings.value("QRZcomPass").toString ());
     QRZCOMLogBookKEYLineEdit->setText(settings.value("QRZcomLogBookKey").toString ());
+    index = QRZCOMSentDefaultComboBox->findText(settings.value("QRZcomSentDefault", "M").toString(), Qt::MatchFixedString);
+    indexBackup = QRZCOMSentDefaultComboBox->findText("M", Qt::MatchFixedString);
+    QRZCOMSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : indexBackup);
     settings.endGroup ();
 
     settings.beginGroup ("LoTW");
-    lotwUseTQSLCheckBox->setChecked (settings.value("LoTWActive").toBool ());
+    lotwUseTQSLCheckBox->setChecked (settings.value("LoTWActive", false).toBool ());
     lotwUserLineEdit->setText (settings.value("LoTWUser").toString ());
     //qDebug() << Q_FUNC_INFO << ": LoTWUser: " << lotwUserLineEdit->text ();
     lotwPasswordLineEdit->setText (settings.value("LoTWPass").toString ());
     lotwTQSLPathLineEdit->setText (settings.value("LoTWPath").toString ());
+    indexBackup = lotwSentDefaultComboBox->findText("Q", Qt::MatchFixedString);
+    index = lotwSentDefaultComboBox->findText(settings.value("LoTWSentDefault", "Q").toString(), Qt::MatchFixedString);
+    lotwSentDefaultComboBox->setCurrentIndex(index >= 0 ? index : indexBackup);
     settings.endGroup ();
 }
