@@ -128,6 +128,7 @@ void SetupPageLogs::slotEditButtonClicked()
       //qDebug() << "SetupPageLogs::slotEditButtonClicked";
     newLog->setStationCallSign(dataProxy->getStationCallSignFromLog(selectedLog));
     newLog->setOperators(dataProxy->getOperatorsFromLog(selectedLog));
+   //qDebug() << Q_FUNC_INFO ;
     newLog->setComment(dataProxy->getCommentsFromLog(selectedLog));
     newLog->setDateString(dataProxy->getLogDateFromLog(selectedLog));
     //newLog->setTypeN(dataProxy->getLogTypeNFromLog(selectedLog).toInt());
@@ -164,26 +165,7 @@ void SetupPageLogs::slotRemoveButtonClicked()
             stringQuery = QString("DELETE FROM log WHERE lognumber='%1'").arg(selectedLog);
             sqlOk = query.exec(stringQuery);
                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery() ;
-            if (sqlOk)
-            {
-                   //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS REMOVED: " << QString::number(selectedLog) << ")";
-                stringQuery = QString("DELETE FROM awarddxcc WHERE lognumber='%2'").arg(selectedLog);
-                query.exec(stringQuery);
-                sqlOk = query.exec();
-                   //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery() ;
-                if (sqlOk)
-                {
-                       //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedLog) << ")";
-                }
-                else
-                {
-                    emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-                    showError(tr("Log has not been removed. (#3)"));
-                       //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedLog) << ")";
-                }
-
-            }
-            else
+            if (!sqlOk)
             {
                 showError(tr("Log has not been removed. (#2)"));
                    //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS NOT REMOVED: " << QString::number(selectedLog) << ")";
@@ -191,7 +173,7 @@ void SetupPageLogs::slotRemoveButtonClicked()
         }
         else
         {
-            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
             showError(tr("Log has not been removed. (#1)"));
                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedLog) << ")";
         }
@@ -339,13 +321,12 @@ QStringList SetupPageLogs::readLogs()
             aux2 = aux2.append(")");
 
             _logs.append(aux2);
-
         }
         return _logs;
     }
     else
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
         return _logs;
     }
 }
@@ -441,19 +422,31 @@ void SetupPageLogs::saveSettings()
 
 void SetupPageLogs::loadSettings()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     Utilities util(Q_FUNC_INFO);
+    //qDebug() << Q_FUNC_INFO << " - 00";
     QSettings settings(util.getCfgFile (), QSettings::IniFormat);
+    //qDebug() << Q_FUNC_INFO << " - 01";
     int i = settings.value("SelectedLog").toInt();
+    //qDebug() << Q_FUNC_INFO << " - 02";
     if (!dataProxy->doesThisLogExist(i))
     {
+        //qDebug() << Q_FUNC_INFO << " - 10";
         i = 0;
-        while((!dataProxy->doesThisLogExist(i)) || i >500)
+        while((!dataProxy->doesThisLogExist(i)) && (i <500))
         {//TODO If a user has more than 500 logs it may fail...
             i++;
+            //qDebug() << Q_FUNC_INFO << " - Log: " << QString::number(i);
         }
+        //qDebug() << Q_FUNC_INFO << " - 49";
     }
+    //qDebug() << Q_FUNC_INFO << " - 50";
     selectedLog = i;
+    //qDebug() << Q_FUNC_INFO << " - 51";
     logsView->selectRow(1);
+    //qDebug() << Q_FUNC_INFO << " - 52";
     QModelIndex index = logsModel->index(selectedLog, 0);
+    //qDebug() << Q_FUNC_INFO << " - 53";
     logsView->setCurrentIndex(index);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
