@@ -793,6 +793,35 @@ int Utilities::getAreaNumberFromCall(const QString &_c)
     return -1;
 }
 
+bool Utilities::isValidIOTA(const QString &_c)
+{
+    QStringList iota;
+    iota.append(_c.split('-'));
+    if (!isValidContinent(iota.at(0)))
+        return false;
+
+    QString number = iota.at(1);
+    bool ok = false;
+    int n = number.toInt(&ok);
+    if (!ok)
+        return false;
+    if (n<=0)
+        return false;
+
+    return true;
+}
+
+int Utilities::getIOTAIdFromIOTA(const QString &_iota)
+{// Returns the numbert IOTA id
+
+    if (!isValidIOTA(_iota))
+        return -1;
+
+    QStringList iota;
+    iota.append(_iota.split('-'));
+    QString number = iota.at(1);
+    return number.toInt();
+}
 
 QString Utilities::getPrefixFromCall(const QString &_c, bool withAreaNumber)
 {
@@ -829,6 +858,8 @@ bool Utilities::isSameFreq(const double fr1, const double fr2)
     //return fabs(fr1 - fr2) < 0.001;
 }
 
+
+/*
 bool Utilities::isValidBandId(const int _b)
 {
     if (_b>0)
@@ -846,7 +877,7 @@ bool Utilities::isValidModeId(const int _m)
 {
     return (_m>0);
 }
-
+*/
 bool Utilities::isValidFreq(const QString &_b)
 {
     return  (_b.toDouble()>0);
@@ -914,7 +945,7 @@ bool Utilities::isValidVUCCGrids(const QString &_b)
 
 bool Utilities::isValidRST(const QString &_b)
 {
-    return (_b.length()>0);
+    return (!_b.isEmpty());
 }
 
 bool Utilities::isValidPower(const QString &_b)
@@ -924,12 +955,12 @@ bool Utilities::isValidPower(const QString &_b)
 
 bool Utilities::isValidComment(const QString &_b)
 {
-    return (_b.length()>0);
+    return (!_b.isEmpty());
 }
 
 bool Utilities::isValidName(const QString &_b)
 {
-    return (_b.length()>0);
+    return (!_b.isEmpty());
 }
 
 bool Utilities::fileExists(const QString &_fileName)
@@ -1016,18 +1047,21 @@ bool Utilities::isValidADIFField(const QString &_b)
 
 bool Utilities::isValidQSL_Rcvd(const QString &c)
 {
-    return ((c == "Y") || (c == "N") || (c == "R") || (c == "I") || (c == "V"));
+    QString v = c.toUpper();
+    return ((v == "Y") || (v == "N") || (v == "R") || (v == "I") || (v == "V"));
 }
 
 bool Utilities::isValidQSL_Sent(const QString &c)
 {
-    return ((c == "Y") || (c == "N") || (c == "R") || (c == "Q") || (c == "I"));
+    QString v = c.toUpper();
+    return ((v == "Y") || (v == "N") || (v == "R") || (v == "Q") || (v == "I"));
 }
 
 bool Utilities::isValidUpload_Status(const QString &c)
 {
    //qDebug() << Q_FUNC_INFO << " - " << c;
-    return ((c == "Y") || (c == "N") || (c == "M"));
+    QString v = c.toUpper();
+    return ((v == "Y") || (v == "N") || (v == "M"));
 }
 
 QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
@@ -1254,7 +1288,7 @@ QDate Utilities::getDateFromSQliteString(const QString &_s)
 
 QDate Utilities::getDateFromADIFDateString(const QString &_s)
 {// Expects an ADIF DATE format string: "YYYYMMDD"
-   //qDebug() << "Utilities::getDateFromADIFDateString: " << _s ;
+    //qDebug() << "Utilities::getDateFromADIFDateString: " << _s ;
     return QDate::fromString(_s, "yyyyMMdd");
 }
 
@@ -1288,7 +1322,6 @@ QDate Utilities::getDateFromLoTWQSLDateString(const QString &_s)
     return QDate::fromString(datet.at(0), "yyyy-MM-dd");
 }
 
-
 QString Utilities::getADIFDateFromQDateTime(const QDateTime &_d)
 {
     return getADIFDateFromQDate(_d.date());
@@ -1350,62 +1383,6 @@ QString Utilities::getCabrilloTimeFromQDateTime(const QDateTime &_d)
     }
 }
 
-QString Utilities::getQSO_CompleteFromADIF(const QString &_s)
-{ // Receives a valid QSO_COMPLETE ADIF data and returns
-  // one char to be stored in the data base.
-  // Default value is Y
-    //Parece que falla al guardar este campo que no se traduce a un varchar(1)
-    //qDebug() << Q_FUNC_INFO << ": " << _s;
-
-    Adif adif(Q_FUNC_INFO);
-    if (!adif.isValidQSO_COMPLETE(_s))
-    {
-        //qDebug() << Q_FUNC_INFO << " No valid";
-        return "1";
-    }
-    if (_s == "N")
-    {
-       return "2";
-    }
-    else if (_s == "NIL")
-    {
-        return "3";
-    }
-    else if (_s == "?")
-    {
-        return "4";
-    }
-    else
-    {
-        return "1";
-    }
-}
-
-QString Utilities::getADIFQSO_CompleteFromDB(const QString &_s)
-{// Returns the ADIF QSO_COMPLETE
-    //1=Y, 2=N, 3=NIL, 4=?
-    //qDebug() << Q_FUNC_INFO << ": " << _s;
-    int i = _s.toInt();
-    switch (i)
-    {
-        case 2:
-        {
-            return "N";
-        }
-        case 3:
-        {
-            return "NIL";
-        }
-        case 4:
-        {
-            return "?";
-        }
-        default:
-        {
-            return "Y";
-        }
-    }
-}
 
 
 QString Utilities::getOnlineServiceName(OnLineProvider _service)
@@ -1602,7 +1579,7 @@ QString Utilities::getLogColumnName(const QString &_column)
 {
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": " << _column;
     QString aux = columnNames.value(_column);
-    if (aux.length()>0)
+    if (!aux.isEmpty())
     {
         return aux;
     }
@@ -1613,7 +1590,7 @@ QString Utilities::getLogColumnDBName(const QString &_column)
 {
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": " << _column;
     QString aux = columnNames.key(_column);
-    if (aux.length()>0)
+    if (!aux.isEmpty())
     {
         return aux;
     }
