@@ -87,7 +87,7 @@ public:
 
     double getLongitude(const int _enti); // Returns the longitude of the Entity
     double getLatitude(const int _enti); // Returns the latitude of the Entity
-
+    int selectEntity(const int _ent1, const int _ent2);     // Useful to return Italy 248 if 248 or 2248 (IT9) are delivered. -1 if no selection can be made
     int getEntityCqz(const int _enti);
     int getQRZCqz(const QString &_qrz);
     //int getPrefixCQz(const QString &_p);
@@ -129,7 +129,7 @@ private:
     bool addPrefixes(const QString &prefixes, int entityNumber, int cqz, int ituz);
     bool insertPrefixes(const QList<QPair<QString, QPair<int, QPair<int, int>>>> &pairPrefixes);
     int extractEntityNumber(const QStringList &stringList);
-
+    bool existingDXCCId(const int _id)  const;                  // TO Check on World creation if a non-DXCC(IT9, IG9, ...) is already existing
     void emitQueryError(const QSqlQuery &query) const;
     bool executeQuery(QSqlQuery &query, const QString &queryString) const;
     //int progressBarPosition;
